<?php
/** Mizo (Mizo ţawng)
 *
 * See MessagesQqq.php for message documentation incl. usage of parameters
 * To improve a translation please visit http://translatewiki.net
 *
 * @ingroup Language
 * @file
 *
 * @author Lpachuau
 * @author RMizo
 */

$messages = array(
# User preference toggles
'tog-underline' => 'Zawmna hnuairinna',
'tog-justify' => 'Hlawm tinte tlang tirual rawh',
'tog-hideminor' => 'Siamţhatna tenau tihdanglam thar zingah tilang suh',
'tog-hidepatrolled' => 'Siamţhat venhim tihdanglam thar zingah tilang suh',
'tog-newpageshidepatrolled' => 'Phêk venhim phêk thar tlarah tilang suh',
'tog-extendwatchlist' => 'A thar chauh ni lo, tihdanglamna zawng zawng tilang tùrin ralvèn kapparh rawh',
'tog-usenewrc' => 'Tihdanglam tharte leh ralvente a phêk azir zëlin tlar rawh (JavaScript a ngai)',
'tog-numberheadings' => 'A thupuite amahin nambar inpêktir rawh',
'tog-showtoolbar' => 'Siamṭhatna hmanraw-liang tilang rawh (JavaScript a ngai)',
'tog-editondblclick' => 'Hmehphìrin phêk siamṭha rawh (JavaScript a ngai)',
'tog-editsection' => 'Hlawm hrang siamṭhatna [siamṭhatna] zawmna hmangin awmtir rawh',
'tog-editsectiononrightclick' => 'Hlawm thupui ding-hmeh hmangin hlawm siamţhat theihna awmtir rawh (JavaScript a ngai)',
'tog-showtoc' => 'A chhunga thu awm te tilang rawh (thupui 3 aia tam phêk tan)',
'tog-rememberpassword' => 'He ka rangpuifannaah hian min hre reng rawh (a rei berah ni $1  {{PLURAL:$1}})',
'tog-watchcreations' => 'Ka phêk siamte leh ka taksa hlankaite ka ralvèn zing-ah telh rawh',
'tog-watchdefault' => 'Ka phêk siamţhatte ka ralvèn zing-ah telh rawh',
'tog-watchmoves' => 'Ka phêk leh taksa sawnte ka ralvèn zing-ah telh rawh',
'tog-watchdeletion' => 'Ka phêk leh taksa nuaibo apiang ka ralvèn zingah telh rawh',
'tog-minordefault' => "Siamţhat tawh phawt chu 'tenau'-ah dah vek rawh",
'tog-previewontop' => 'Siamţhatna bawm hmaah endikna dah rawh',
'tog-previewonfirst' => 'Siamţhat vawi khatnaah endikna tilang rawh',
'tog-nocache' => 'Fanna-in phêk a cache tur veng rawh',
'tog-enotifwatchlistpages' => 'Ka ralvèn zinga phêk emaw taksa pakhat tihdanglam a nih apiangin e-lehkha min thawn rawh',
'tog-enotifusertalkpages' => 'Ka hmangtu-sawihona phêk tihdanglam a nihin e-lehkha min thawn rawh',
'tog-enotifminoredits' => 'Phêk leh taksa siamţhat tenauah pawh e-lehkha min thawn tho rawh',
'tog-enotifrevealaddr' => 'Hriattirna email zingah ka email address pho lang rawh',
'tog-shownumberswatching' => 'Ralvèngtu zât tilang rawh',
'tog-oldsig' => 'Khàrna hming hman mék:',
'tog-fancysig' => 'Khàrna hming wikithu angah ngai rawh (zawmna insiam ţül lovin)',
'tog-uselivepreview' => 'Endikna nung hmang rawh (JavaScript a ngai) (hei hi chhinna chauh a la ni)',
'tog-forceeditsummary' => 'Siamţhatna ruak ka dahluh palhin min hrilh rawh',
'tog-watchlisthideown' => 'Ka siamţhatho ka ralvènah telh suh',
'tog-watchlisthidebots' => 'Bot siamţhatho ralvèn zing-ah telh suh',
'tog-watchlisthideminor' => 'Siamţhat tenau ralvèn zing aţang thup rawh',
'tog-watchlisthideliu' => 'Ralvèn zing aţang hmangtu inziaklut siamţhat tibo rawh.',
'tog-watchlisthideanons' => 'Hmangtu hriat lohvina an siamţhat ralvèn zing aţang',
'tog-watchlisthidepatrolled' => 'Siamţhat viltu nei ralvèn zingah telh suh',
'tog-ccmeonemails' => 'Hmangtu dang hnena ka e-lehkha thawn apiang min thawn ve zel rawh',
'tog-diffonly' => 'Dnglmn hnuaiah phêk chhúng tilang suh',
'tog-showhiddencats' => 'Pawl thuhrûkho tilang rawh',
'tog-norollbackdiff' => 'Lumlêt hnuah dnglmn kalkan rawh',
'tog-useeditwarning' => 'Ka phêk siam danglamna ka dahţhat theihnghilh palh chuan min hrilh rawh',

'underline-always' => 'Ziah/ngei ngei',
'underline-never' => 'Ngai lo',
'underline-default' => 'Vun leh rängpuifanna duhdàn',

# Font style option in Special:Preferences
'editfont-style' => 'Siamţhatna hmun hawrawp pian',
'editfont-default' => 'Rängpuifanna duhdàn',
'editfont-monospace' => 'Hawrawp inkar rualkhai',
'editfont-sansserif' => 'Sans-serif hawrawp',
'editfont-serif' => 'Serif hawrawp',

# Dates
'sunday' => 'Pathianni',
'monday' => 'Thawhţanni',
'tuesday' => 'Thawhlehni',
'wednesday' => 'Nilaini',
'thursday' => 'Ningani',
'friday' => 'Zirtawpni',
'saturday' => 'Inrinni',
'sun' => 'Ptn',
'mon' => 'Thṭ',
'tue' => 'Thl',
'wed' => 'Nil',
'thu' => 'Nng',
'fri' => 'Zrt',
'sat' => 'Inr',
'january' => 'Pawlkut',
'february' => 'Ramtuk',
'march' => 'Vau',
'april' => 'Ṭau',
'may_long' => 'Ṭomir',
'june' => 'Nikir',
'july' => 'Vawkhniahzawn',
'august' => 'Thiṭin',
'september' => 'Mimkut',
'october' => 'Khuangchawi',
'november' => 'Sahmulphah',
'december' => 'Pawltlak',
'january-gen' => 'Pawlkût thla',
'february-gen' => 'Ramtuk thla',
'march-gen' => 'Vau thla',
'april-gen' => 'Ṭau thla',
'may-gen' => 'Ţomir thla',
'june-gen' => 'Nikir thla',
'july-gen' => 'Vawkhniahzawn thla',
'august-gen' => 'Thiţin thla',
'september-gen' => 'Mimkut thla',
'october-gen' => 'Khuangchawi thla',
'november-gen' => 'Sahmulphah thla',
'december-gen' => 'Pawltlak thla',
'jan' => 'Pkt',
'feb' => 'Rtk',
'mar' => 'Vau',
'apr' => 'Ṭau',
'may' => 'Ṭmr',
'jun' => 'Nkr',
'jul' => 'Vhz',
'aug' => 'Tţn',
'sep' => 'Mkt',
'oct' => 'Kch',
'nov' => 'Shp',
'dec' => 'Ptk',

# Categories related messages
'pagecategories' => '{{PLURAL:$1|Pawl|Pawlte}}',
'category_header' => '"$1" pawla phêkte',
'subcategories' => 'Pawlpengte',
'category-media-header' => '"$1" pawla mediate',
'category-empty' => '"He pawl hian phêk leh media pakhat mah a nei hrih lo."',
'hidden-categories' => 'Pawl thuhrûk{{PLURAL:$1||te}}',
'hidden-category-category' => 'Pawl thuhrûkte',
'category-subcat-count' => '{{PLURAL:$2|He pawl hian he pawlpeng chauh hi a nei. |He pawl hian heng  {{PLURAL:$1|pawlpéng|pawlpéng $1-te}} hi a nei, avaia  $2  zingah.}}',
'category-subcat-count-limited' => "He pawl hian  {{PLURAL:$1|hë pawlpéng chauh|$1 hê'ng pawlpéngte}} hi a nei.",
'category-article-count' => "{{PLURAL:$2|He pawl hian hemi phêk chauh hi a nei. | Hê'ng phek {{PLURAL:$1||$1-te}} hi he pawlah hian a awm, avaia $2 zingah.}}",
'category-article-count-limited' => '{{PLURAL: $1 |$1He|$1 Heng}} phekte hi hë pawl, i en mékah hian a awm.',
'category-file-count' => '{{PLURAL:$2|He pawl hian hë taksa chauh hi a kengtel.|{{PLURAL:$1|He taksa $1 |Heng taksa $1-te}} hi he pawlah hian a awm, a vaia $2 zingah}}',
'category-file-count-limited' => '{{PLURAL:$1|He taksa|$1Heng taksate}} hi hemi pawl, i en mékah hian a awm.',
'listingcontinuesabbrev' => 'chhunz.',
'index-category' => 'Phêk tarlante',
'noindex-category' => 'Phêk tarlan lohte',
'broken-file-category' => 'Taksa kehchhe zawmna awm phêkte',

'about' => 'Chungchang',
'article' => 'A chhunga thu awm',
'newwindow' => '(Tukverh tharah a inhawng ang)',
'cancel' => 'Sûtna',
'moredotdotdot' => 'Chhunzawmna...',
'morenotlisted' => 'Tarlan loh dang...',
'mypage' => 'Phêk',
'mytalk' => 'Sawihona',
'anontalk' => 'He chenhmun-IP tana sawihona',
'navigation' => 'Fanzauna',
'and' => '&#32;leh',

# Cologne Blue skin
'qbfind' => 'Zawng rawh',
'qbbrowse' => 'Fangvêl rawh',
'qbedit' => 'Siamṭhatna',
'qbpageoptions' => 'He phêk hi',
'qbmyoptions' => 'Ka phêkte',
'qbspecialpages' => 'Phêk vohbîkte',
'faq' => 'Zawhzin',
'faqpage' => 'Project: Zawhzin',

# Vector skin
'vector-action-addsection' => 'Thupui belhna',
'vector-action-delete' => 'Paihna',
'vector-action-move' => 'Sawnna',
'vector-action-protect' => 'Venhimna',
'vector-action-undelete' => 'Lak kir lehna',
'vector-action-unprotect' => 'Venhimna dinhmun tidanglam rawh',
'vector-simplesearch-preference' => 'Zawn awlsam lehzualna rawtna awmtir rawh (Vektawr vun tan chauh)',
'vector-view-create' => 'Siamna',
'vector-view-edit' => 'Siamţhatna',
'vector-view-history' => 'Hunhlui-chanchin',
'vector-view-view' => 'Chhiarna',
'vector-view-viewsource' => 'A hnar enna',
'actions' => 'Thiltih',
'namespaces' => 'Hminghmun',
'variants' => 'Zedang',

'navigation-heading' => 'Fankualna',
'errorpagetitle' => 'Dik lo',
'returnto' => '$1 phekah kir leh rawh.',
'tagline' => '{{SITENAME}} aṭangin',
'help' => 'Ṭanpuina',
'search' => 'Zawnna',
'searchbutton' => 'Zawng rawh le',
'go' => 'Khai le',
'searcharticle' => 'Khai le',
'history' => 'Phêk chanchin',
'history_short' => 'Chanchin',
'updatedmarker' => 'ka tlawh hnuhnun ber hnua tihdanglam',
'printableversion' => 'Chhụtkài theih',
'permalink' => 'Hlet hlun',
'print' => 'Chhụkàina',
'view' => 'Enna',
'edit' => 'Siamṭhatna',
'create' => 'Siamna',
'editthispage' => 'He phek hi siamţha rawh',
'create-this-page' => 'He phêk hi siam rawh',
'delete' => 'Paihna',
'deletethispage' => 'He phêk hi paih rawh',
'undelete_short' => 'Siamţhat vawi {{PLURAL:$1|khat| $1}} la kïr leh rawh.',
'viewdeleted_short' => 'Nuaibo hnu siamţhat vawi {{PLURAL:$1|khat|$1}} thleng la kïr leh rawh.',
'protect' => 'Venhimna',
'protect_change' => 'tihdanglamna',
'protectthispage' => 'He phêk hi venghim rawh',
'unprotect' => 'Vanhimna dinhmun tidanglam rawh',
'unprotectthispage' => 'He phêk venhimna dinhmun hi tidanglam rawh',
'newpage' => 'Phek thar',
'talkpage' => 'He phêk sawihonaah hian tel rawh',
'talkpagelinktext' => 'Sawihona',
'specialpage' => 'Vohbik phek',
'personaltools' => 'Mimal hmanruate',
'postcomment' => 'Thuhlawm thar',
'articlepage' => 'A chhungthu enna',
'talk' => 'Sawihona',
'views' => 'Thlirna',
'toolbox' => 'Hmanrawbawm',
'userpage' => 'Hmangtu phek enna',
'projectpage' => 'Beihpui phêkpui enna',
'imagepage' => 'Taksa phêk enna',
'mediawikipage' => 'Thudawn phêk enna',
'templatepage' => 'Siamsa phêk enna',
'viewhelppage' => 'Ţanpuina phêk enna',
'categorypage' => 'Pawl phêk enna',
'viewtalkpage' => 'Sawinona en rawh',
'otherlanguages' => 'Ṭawng dangin',
'redirectedfrom' => '($1 aṭanga hruailuh a ni)',
'redirectpagesub' => 'Hruailuhna phêk',
'lastmodifiedat' => 'Hemi phek hi ni $1,  dar $2 khan siamṭhat hnuhnun ber a ni.',
'viewcount' => 'He phêk hi vawi {{PLURAL:$1|khat|$1}} tlawh a ni tawh.',
'protectedpage' => 'Phêk venhim',
'jumpto' => 'Tah hian kal rawh:',
'jumptonavigation' => 'fanzauna',
'jumptosearch' => 'zawnna',
'view-pool-error' => 'A pawi hle mai, server overload a ni.
Hmangtu tam leh lutukin he phêk hi en an tum a. 
En i tum leh hmain rei lo të nghâk ang che.

$1',
'pool-timeout' => 'Khar hun a tawp ta',
'pool-queuefull' => 'Hnathawhna hmun awl a awm tawh lo',
'pool-errorunknown' => 'Kan hriatthiam loh dikhlel a awm tlat',

# All link text and link target definitions of links into project namespace that get used by other message strings, with the exception of user group pages (see grouppage).
'aboutsite' => '{{SITENAME}}  chungchang',
'aboutpage' => 'Project:Chungchang',
'copyright' => 'A chhung thute hi $1 hmanga lakchhawn phal a ni.',
'copyrightpage' => '{{ns:project}}:Lakchhawn phalphung',
'currentevents' => 'Chanchinthar',
'currentevents-url' => 'Project: Chanchin thar',
'disclaimers' => 'Intlawhkhalhna',
'disclaimerpage' => 'Project: Intlawhkhalhna Dan',
'edithelp' => 'Siamţhat zirna',
'helppage' => 'Help: A chhunga thu awmte',
'mainpage' => 'Phekpui',
'mainpage-description' => 'Phekpui',
'policy-url' => 'Project: Dàn',
'portal' => 'Kawtchhuahpui',
'portal-url' => 'Project: Kawtchhuahpui',
'privacy' => 'Inthupna dan',
'privacypage' => 'Project: Inthupna dan',

'badaccess' => 'Phalna dikhlel',
'badaccess-group0' => 'Tuna i thil tih tum kha tih phalsak i ni lo.',
'badaccess-groups' => 'Tuna i thil tih tum kha {{PLURAL:$2|hemi chauh hi tih phalsak a ni|heng mite chauh hi tih phalsak an ni}}: $1.',

'versionrequired' => 'MediaWiki chhuah $1-na a ngai.',
'versionrequiredtext' => 'He phêk hmang tur hian MediaWiki chhuah $1 a ngai.
[[Special:Version|version page]] en rawh.',

'ok' => 'Aw le',
'retrievedfrom' => '"$1" aṭanga lâk chhuah',
'youhavenewmessages' => '($2) $1 i nei.',
'newmessageslink' => 'thudawn thar',
'newmessagesdifflink' => 'tihdanglam thar',
'youhavenewmessagesfromusers' => 'Hmangtu dang {{PLURAL:$3|pakhat|$3}} hnên aṭang $1 i nei ($2)',
'youhavenewmessagesmanyusers' => 'Hmangtu dang tamtak hnên aṭang $1 i nei nual ($2)',
'newmessageslinkplural' => '{{PLURAL:$1|thudawn thar}}',
'newmessagesdifflinkplural' => '{{PLURAL:$1|tihdanglam}} thar',
'youhavenewmessagesmulti' => '$1-ah thu dawn thar i nei',
'editsection' => 'siamṭhatna',
'editold' => 'siamṭhatna',
'viewsourceold' => 'A hnar enna',
'editlink' => 'siamṭhatna',
'viewsourcelink' => 'a hnar enna',
'editsectionhint' => 'Hemi thuhlawm hi siamţha rawh le: $1',
'toc' => 'A chhung thute',
'showtoc' => 'pharhna',
'hidetoc' => 'thlehna',
'collapsible-collapse' => 'Thlehna',
'collapsible-expand' => 'Pharhna',
'thisisdeleted' => '$1 hi en emaw, dah lêt leh emaw i duh em?',
'viewdeleted' => '$1 i en duh em?',
'restorelink' => '{{PLURAL:$1| vawi khat nuaibo|vawi $1 nuaibo tawh}} siamţhatna',
'feedlinks' => 'Chàwmna:',
'feed-invalid' => 'Chawmna dik lo.',
'feed-unavailable' => 'Syndication chawm-letna tih theih a ni lo',
'site-rss-feed' => 'RSS chawmna $1',
'site-atom-feed' => 'Chawmna riang $1',
'page-rss-feed' => 'RSS chawmna "$1"',
'page-atom-feed' => 'Chawmna riang "$1"',
'red-link-title' => '$1 (Hemi phek hi a la awm lo. Hetah hian hmet la tlawmngaiin siam ţan rawh le)',
'sort-descending' => 'A lêt zawnga remna',
'sort-ascending' => 'A indawta remna',

# Short words for each namespace, by default used in the namespace tab in monobook
'nstab-main' => 'Phek',
'nstab-user' => 'Hmangtu phek',
'nstab-media' => 'Media phek',
'nstab-special' => 'Vohbik phek',
'nstab-project' => 'Hna-hmachhawp phek',
'nstab-image' => 'Taksa',
'nstab-mediawiki' => 'Thu',
'nstab-template' => 'Siamsa',
'nstab-help' => 'Ţanpuina phek',
'nstab-category' => 'Pawl',

# Main script and global functions
'nosuchaction' => 'Hetiang hi a tih theih loh',
'nosuchactiontext' => 'URL-a tihtur lang hi a tihtheih loh.
URL i chhu dik lo a ni mai thei, emaw zawm dik loah i kal a niang.
{{SITENAME}} khawlthlûak hmanah hian dik tawk lo lai a awm a ni thei bawk.',
'nosuchspecialpage' => 'Hetiang vohbik phek hi a awm lo',
'nospecialpagetext' => '<strong>Vohbik phek awm lo en i tum.</strong>

Vohbik phekte chu hetah hian a en theih [[Special:SpecialPages|{{int:specialpages}}]].',

# General errors
'error' => 'Dik lo',
'databaseerror' => 'Database dik loh',
'laggedslavemode' => "'''Vaukhanna:''' He phêk hian tun hnaia siam thar a pho lang lo mai thei.",
'readonly' => 'Database kalh a ni',
'enterlockreason' => 'I kalhna chhan leh i hawn leh hun tura i rin sawi rawh',
'missing-article' => 'Database-in a hmuh tùr phêk "$1" $2 a hmu lo tlat mai. 

Hei hi dnglm ţhing emaw phêk paih tawh zawmna hlui zui vanga awm a ni tlangpui. 

Chumi a nih si loh chuan khawlthluakah hrik ţhalo i tawng tihna a ni ang. Khawngaihin [[Special:ListUsers/sysop|roreltu]] hnenah  a URL chiang taka sawiin hrilh rawh.',
'missingarticle-rev' => '(siamṭhatna zât: $1)',
'missingarticle-diff' => '(Diff: $1, $2)',
'readonly_lag' => 'Database salin a pu a umphâk laiin database amahin inkhar behtir a ni.',
'internalerror' => 'Chhunglam dik loh',
'internalerror_info' => 'Chhunglam dik loh: $1',
'fileappenderrorread' => 'A hmawrbawk laiin "$1" a chhiar thei lo.',
'fileappenderror' => '"$1"-a "$2" hmawrbawk theih a ni lo.',
'filecopyerror' => 'Taksa "$1" hi "$2"-a lakchhawn theih a ni lo.',
'filerenameerror' => 'Taksa "$1" hi hming dang, "$2"-ah a thlâk thei lo.',
'filedeleteerror' => 'Taksa "$1" nuaibo thei lo tlat.',
'directorycreateerror' => 'Bawmpui "$1" siam theih a ni lo.',
'filenotfound' => 'Taksa "$1" hmuh theih a ni lo.',
'fileexistserror' => 'Taksa "$1" ziah theih a ni lo: Taksa chu a awm si.',
'unexpected' => 'Hlutzawng beisei loh: "$1"="$2".',
'formerror' => 'Dikhlel: Lehkha thehluh theih a ni lo.',
'badarticleerror' => 'He phêkah hian tuna i tih tum ang kha tih theih a ni lo.',
'cannotdelete' => 'He taksa / phêk "$1" hi nuaibo theih a ni lo.
Tu emawin a nuaibo tawh a ni ang.',
'cannotdelete-title' => '"$1" phêk hi nuaibo theih a ni lo.',
'badtitle' => 'Hming dikhlel',
'badtitletext' => 'I phêk zawn kha a hming a dik lo emaw, a ruak emaw, ţawng dang wiki hming nèn ţhui sual emaw a nih hmel. 
Phêk hminga hman theih loh hawrawp pahnih-khat a awm a ni mai thei bawk.',
'querypage-no-updates' => 'He phêk tihdanglamna hi khàr hrih a ni.
Heta châk (hmanrua) reng reng thlâk thar a ni hrih mai lo vang.',
'wrong_wfQuery_params' => 'wfQuery()<br />-ah châkkhai dik lo a awm.
Hnathawh: $1<br />
Thil zawn: $2',
'viewsource' => 'A hnar enna',
'viewsource-title' => '$1 hnar en rawh',
'actionthrottled' => 'Thiltih upbeh a ni.',
'actionthrottledtext' => 'Thu dukdak lo ven nan hun rei lo te chhunga vawi tam tak tih nawn phal loh a ni, i thiltih ngai i tihnawn ngun tawh lutuk avangin dan beh hrih i ni. Nakin deuhvah tum chhin leh rawh.',
'protectedpagetext' => 'He phêk hi khawih danglam theih emaw tihchingpen theih loh nana venhim hrih a ni.',
'viewsourcetext' => 'A hnar i lachhawngin i en thei ang:',
'viewyourtext' => "'''I siamţhatte''' chu he phêkah hian i enin i lachhawng thei ang.",
'protectedinterface' => 'He phêk hian khawlthluak tan hmangtu-ţawng a phuhru a, hman khawloh a nih loh nan venhim hrih a ni. Lehlinna tidanglam tur emaw belh tur chuan [//translatewiki.net/ translatewiki.net], MediaWiki lehzauna hmachhawp hi i hmang dawn nia.',
'cascadeprotected' => 'He phêk hi siam danglam phal a ni hrih lo, a chhan chu {{PLURAL:$1|he phêk|hêng phêk}}, "a huhova venhim" tih hmanga ven chhunga awm a nih vang a ni: 
$2',
'namespaceprotected' => "'''$1''' tih hminghmun chhunga phêkte siamţhat phalna i nei lo.",
'customcssprotected' => 'Hmangtu dang mimal thil a awm avangin he CSS phêk hi siam danglam phal a ni lo.',
'customjsprotected' => 'Hmangtu dang mimal thil a tel avangin he JavaScript phêk hi siamţhat phalsak i ni lo.',
'ns-specialprotected' => 'Phêk vohbîkte siam danglam theih a ni lo.',
'titleprotected' => 'He phêk hi hmangtu [[User:$1|$1]] siam phalsak a ni lo. A chhan hetah: "\'\'$2\'\'" hian pêk a ni.',
'invalidtitle-knownnamespace' => 'Hming pawm loh hminghmun "$2"-a "$3" tih thu chuang.',
'invalidtitle-unknownnamespace' => 'Hming pawm loh leh hminghmun zât hriat loh $1-a thu chuang "$2"',
'exception-nologin' => 'I la lût lo',
'exception-nologin-text' => 'I thiltih emaw hawn tum ti thei tur hian  he wiki-ah hian i luh a ngai',

# Virus scanner
'virus-badscanner' => "Inremdan dikhlel: Hrik thiantu hriat loh: ''$1''",
'virus-scanfailed' => 'Hrik then a hlawhchham (thutûk $1)',
'virus-unknownscanner' => 'Hrikthiantu hriat loh:',

# Login and logout pages
'logouttext' => "'''I chhuak fel ta.'''
Inziaklût kher lovin {{SITENAME}} hi i hmang chhunzawm thei ang, a nih loh vëk pawhin hmangtu hming pangngai emaw, a hming dang emawin <span class='plainlinks'>[$1 lût leh]</span> thei ang.
I fangtu cache i thenfai hma chu phêk ţhenkhat intar lang a awm reng mai thei, i la  chhuak lo emaw tih mai tùrin.",
'welcomeuser' => 'Chibai, $1!',
'welcomecreation-msg' => 'I siangchan siam fel a ni ta.
[[Special:Preferences|{{SITENAME}}-a i duhphung]] thlâk theihnghilh suh ang che.',
'yourname' => 'Hmangtuhming:',
'yourpassword' => 'Thurûk:',
'yourpasswordagain' => 'Thurûk ziak nawn leh rawh le:',
'remembermypassword' => 'He ka rangpuifanna hman mék (browser)-ah hian ka luhna (a rei berah ni {{PLURAL:$1||}}$1) min vawnsak rawh, thurûk ziah nawn ngai lo tùrin.',
'yourdomainname' => 'I ram:',
'password-change-forbidden' => 'Hë wiki-ah hian thurûk i thlâk thei lo.',
'externaldberror' => 'Insawifiahna felfai lo a awm lo a nih loh vëk pawhin i pawnlam siangchan tihdanglam phalsak i ni lo a ni ang.',
'login' => 'Luhna',
'nav-login-createaccount' => 'Luhna / siangchan siamna',
'loginprompt' => '{{SITENAME}}-a lût tùrin cookie i zuah zalen a ngai.',
'userlogin' => 'Luhna/Siangchan siamna',
'userloginnocreate' => 'Inziah luhna',
'logout' => 'Chhuahna',
'userlogout' => 'Chhuahna',
'notloggedin' => 'I la lût lo',
'nologin' => 'Siangchan i la nei lo maw? $1.',
'nologinlink' => 'Siangchan siam rawh',
'createaccount' => 'Siangchan siam rawh le',
'gotaccount' => 'Siangchan i nei tawh sa maw? $1.',
'gotaccountlink' => 'Luhna',
'userlogin-resetlink' => 'I inziahluhna i theihnghilh maw?',
'createaccountmail' => 'E-lehkhathawnin',
'createaccountreason' => 'Chhan:',
'badretype' => 'I thurûk ziahte a inmil lo.',
'userexists' => 'Hmangtu hming hman tawh a ni.
Hming dang i thlan a ngai.',
'loginerror' => 'Inziahluh sual',
'createaccounterror' => 'Siangchan siam theih loh: $1',
'noname' => 'Hmangtu hming dik a ziak lo.',
'loginsuccesstitle' => 'Hlawhtling takin i lût tâ e.',
'loginsuccess' => "'''{{SITENAME}}-ah \"\$1\" hming puin a i lût ta.'''",
'nosuchuser' => 'Hmingtuhming "$1" a awm lo.
Hmangtuhming hi hawrawppui leh të thliar hran a ngai a ni (entirna: Thara leh thara an inang lo).
I thilziah enfiah rawh, a nih loh pawhin [[Special:UserLogin/signup|siangchan thar siam rawh]].',
'nosuchusershort' => 'Hmangtu hming "$1" a awm lo.
I thilziah enfiah rawh.',
'nouserspecified' => 'Hmangtuhming i ziah a ngai.',
'login-userblocked' => 'Hë hmangtu hi danbeh a ni. Luh phalsak a ni lo.',
'wrongpassword' => 'Thurûk dik lo.
Khawngaihin tum nawn leh rawh.',
'wrongpasswordempty' => 'Thurûk i ziak lo.
Khawngaihin tum ţha leh rawh.',
'passwordtooshort' => 'Thurûk {{PLURAL:$1|hawrawp 1|hawrawp $1}} tala sei a ni tùr a ni.',
'password-name-match' => 'I hmangtuhming leh i thurûk a inang thiang lo.',
'password-login-forbidden' => 'He hmangtuhming leh thurûk hi hman khap a ni.',
'mailmypassword' => 'Thurûk thar e-thawn rawh',
'passwordremindertitle' => '{{SITENAME}} tana thurûk lailâwk.',
'noemail' => 'Hmangtu "$1" tä e-chenhmun ziaksa kan nei lo tlat.',
'noemailcreate' => 'E-chenhmun dik i ziah a ngai.',
'passwordsent' => '"$1" tana i e-chenhmun pêkah thurûk thawn a ni ta.
I dawn hnuah i lût dawn nia.',
'blocked-mailpassword' => 'Phêkte khawih danglam thei lo tùrin i IP hi danbeh a ni; hman khawlohna vèn nan i thurûk dawn lêt leh phalsak i ni tawh lo.',
'mailerror' => 'e-Lehkha thawn sual: $1',
'emailauthenticated' => 'I e-chenhmun $2, $3-ah finfiah a ni.',
'emailnotauthenticated' => 'I e-chenhmun finfiah a la ni lo.
A hnuaia mi eng vang pawh hian e-lehkha thawn a ni lo vang:',
'noemailprefs' => 'Hengte hi tih theih tùr chuan i duhdànah i e-chenhmun telh rawh.',
'emailconfirmlink' => 'I e-chenhmun tichiang rawh',
'invalidemailaddress' => 'A awmphung a dik loh avangin he e-chenhmun hi pawm theih a ni lo.
E-chenhmun dik tak ziaklût rawh, a nih loh leh thai reh vek rawh.',
'cannotchangeemail' => 'He wiki-ah hian siangchan e-chenhmun thlâk theih a ni lo.',
'emaildisabled' => 'Hë rangpuihmun hian e-lehkha a thawn thei lo',
'accountcreated' => 'Siangchan siamfel a ni ta.',
'accountcreatedtext' => '$1 tana hmangtu siangchan siamfel a ni ta.',
'createaccount-title' => '{{SITENAME}} tana siangchan siam',
'createaccount-text' => 'Tüemawin {{SITENAME}}-ah ($4) i e-chènhmun hmangin "$2" tih hming púin, thurûka "$3" tih hmangin siangchan a lo siam a.
Thurûk tidanglam tùrin i luh vat a ngái.

Hë siangchan hi siam sual palh a nih chuan hë thuthawn hi i ngaihthah dáwn nia.',
'usernamehasherror' => 'Hmangtuhmingin bawhtah lem a hmang thiang lo',
'login-throttled' => 'Tunhnai maiah luh i tum ngun lutuk.
I tum leh hmain nghâk lawk ang che.',
'login-abort-generic' => 'I luh tumna a hlawhchham - Pamţùl a ni',
'loginlanguagelabel' => 'Ţawng: $1',

# Email sending
'user-mail-no-addy' => 'E-chenhmun awm lova e-lehkha thawn i tum.',

# Change password dialog
'resetpass' => 'Thurûk thlâkna',
'resetpass_header' => 'Siangchan thurûk thlâkna',
'oldpassword' => 'Thurûk hlui',
'newpassword' => 'Thurûk thar:',
'retypenew' => 'Thurûk ziak nawn leh rawh le:',
'resetpass_submit' => 'Thurûk siamfel la inziaklût rawh',
'changepassword-success' => 'I thurûk hlawhtling taka thlâk a ni.
Kan hruai lût mék a che...',
'resetpass_forbidden' => 'Thurûk thlâk theih a ni lo.',
'resetpass-no-info' => 'He phêk lut mai tùr chuan i inziahluh a ngai.',
'resetpass-submit-loggedin' => 'Thurûk thlâkna',
'resetpass-submit-cancel' => 'Sûtna',
'resetpass-wrong-oldpass' => 'Thurûk dik lo emaw thi tawh.
I thurûk i thlâk hlawhtling tawh a nih loh pawhin thurûk lailâwk i dil a ni thei.',
'resetpass-temp-password' => 'Thurûk lailâwk:',

# Special:PasswordReset
'passwordreset' => 'Thurûk ziakţha rawh',
'passwordreset-legend' => 'Thurûk ziakţha rawh',
'passwordreset-username' => 'Hmangtu hming:',
'passwordreset-domain' => 'Huamchin:',
'passwordreset-email' => 'E-chenhmun:',
'passwordreset-emailtitle' => '{{SITENAME}}-a siangchan chanchin kim',
'passwordreset-emailelement' => 'Hmangtuhming: $1
Thurûk lailâwk: $2',
'passwordreset-emailsent' => 'Hriat nawntirna e-lehkha thawn fel a ni.',
'passwordreset-emailsent-capture' => 'Hriat nawntirna e-lehkha thawn a ni, a hnuaia tarlan ang khuan.',
'passwordreset-emailerror-capture' => 'Hriat nawntirna e-lehkha siam chhuah a ni a, a hnuaia tarlan ang khuan; mahsé thawn hlawhchham a ni: $1',

# Special:ChangeEmail
'changeemail' => 'E-chenhmun thlâk rawh',
'changeemail-header' => 'Siangchan e-chenhmun thlâk rawh',
'changeemail-text' => 'I e-chenhmun thlâk tùrin hei hi dahkhat vek rawh. I tihdanglam nemngheh nan i thurûk ziahluh i ngai ang.',
'changeemail-no-info' => 'He phêk lut mai tùr chuan i inziahluh a ngai.',
'changeemail-oldemail' => 'Tùna i e-chenhmun:',
'changeemail-newemail' => 'E-chenhmun thar:',
'changeemail-none' => '(pakhat mah)',
'changeemail-password' => 'I {{SITENAME}} thurûk:',
'changeemail-submit' => 'E-chenhmun thlâk rawh',
'changeemail-cancel' => 'Sûtna',

# Edit page toolbar
'bold_sample' => 'Hawrawp thau',
'bold_tip' => 'Hawrawp thau',
'italic_sample' => 'Hawrawp äwn',
'italic_tip' => 'Hawrawp äwn',
'link_sample' => 'Zawmna hming',
'link_tip' => 'Inzawm chhawnna',
'extlink_sample' => 'http://www.example.com zawmna hming',
'extlink_tip' => 'Pawnlam zawmna (http:// tih hmabet kha theihnghilh suh la)',
'headline_sample' => 'Thupui',
'headline_tip' => 'Chhawng 2-na thupui',
'nowiki_sample' => 'Hetah hian thu siamrem sa ni lo dahlut rawh',
'nowiki_tip' => 'Wiki siamrem ngaihthah rawh',
'image_tip' => 'Taksa telh',
'media_tip' => 'Taksa zawmna',
'sig_tip' => 'I hmingnem leh hun',
'hr_tip' => 'Rin khamphei (ren deuh la)',

# Edit pages
'summary' => 'A thu tlangpui (laktawi):',
'subject' => 'Thupui:',
'minoredit' => 'Hei hi siamţhatna tenau a ni',
'watchthis' => 'He phêk hi vil rawh',
'savearticle' => 'Tlangzarh rawh le',
'preview' => 'Enchhinna',
'showpreview' => 'Tlangzarh hmaa endikna',
'showlivepreview' => 'Endik thuakna',
'showdiff' => 'Tihdanglam tihlanna',
'anoneditwarning' => "'''Vaukhanna:''' I inziaklût lo tlat.
I chenhmun-IP he phêk chanchinah chhinchhian a ni ang.",
'anonpreviewwarning' => "''I inziaklût lo. I dahţhat chuan he phêk siamţhat chanchinah i chenhmun-IP hi chhinchhian a ni ang.''",
'missingsummary' => "'''Hriat reng tur:''' I siamţhat tlangpui kaihtawina i lo ziak lo tlat.
\"{{int:savearticle}}\" i hmeh leh chuan i thuziah hi a kaihtawina tel lovin dahţhat a ni ang.",
'missingcommenttext' => 'Tuihnihna a hnuaiah khuan ziak rawh.',
'missingcommentheader' => "'''Hriat reng tur:''' I tuihnihna thupui i pe lo.
\"{{int:savearticle}}\"-ah i hmeh leh chuan i siamţhatna hi a thupui tel lovin dahţhat a ni ang.",
'summary-preview' => 'Kaihtawina endikna:',
'subject-preview' => 'Thupui endikna:',
'blockedtitle' => 'He hmangtu hi danbeh a ni',
'blockednoreason' => 'a chhak pêk a ni lo',
'whitelistedittext' => 'Siamţha thei turin $1 i mamawh.',
'confirmedittext' => 'Phêk i siamţhat hmain i e-chenhmun i finfiah a ngai. [[Special:Preferences|hmangtu duhthlanna]] kaltlangin i e-chenhmun siamfel rawh.',
'nosuchsectiontitle' => 'I zawn hlawm hi hmuh theih a ni lo',
'nosuchsectiontext' => 'Hlawm awm lo siamţhat i tum.
A phêk i en chhungin sawn emaw nuaibo emaw a ni a ni ang.',
'loginreqtitle' => 'Inziahluh a ngai',
'loginreqlink' => 'Inziah luhna',
'loginreqpagetext' => 'Phêk dang en tùrin $1 a ngai.',
'accmailtitle' => 'Thurûk kan thawn fel tawh e.',
'accmailtext' => '[[User talk:$1|$1]] tan a kahpaha siam thurûk $2 hnenah thawn a ni tawh.
I siangchan thurûk hi [[Special:ChangePassword|thurûk tihdanglamna]]-ah i inziahluh hnuah i tidanglam thei ang.',
'newarticle' => '(A thar)',
'newarticletext' => "Phêk awm lo zawmna i rawn zui lut a ni. Phêk siam tùrin a hnuaia bawmah khuan chhu rawh (hriattirna dang [[{{MediaWiki:Helppage}}|ţanpuina phêk]]-ah a en theih).
Tihsual palh thilthua heta lo lût i nih chuan i rangpuifanna-a '''letna''' fei zawnah hmet rawh.",
'noarticletext' => 'He phêkah hian thu a la awm hrih lo.
Phêk dangah [[Special:Search/{{PAGENAME}}| he phêk hming hi i zawng]] thei ang, a nih loh pawhin a laichin 
<span class="plainlinks">[{{fullurl:{{#Special:Log}} | page={{FULLPAGENAMEE}}}} chanchin-ziak dang i zawng thei ang]; a nih loh chuan [{{fullurl:{{FULLPAGENAME}}|action=edit}} he phêk hi i siamţha thei ang] </span>.',
'noarticletext-nopermission' => 'He phêkah hian thu a la awm hrih lo.
He phêk hming hi hmun dangah i [[Special:Search/{{PAGENAME}}|zawng]] thei ang, a nih loh pawhin <span class="plainlinks">[{{fullurl:{{#Special:Log}}|page={{FULLPAGENAMEE}}}}-a a laichin chanchin dang] i zawng thei bawk ang,</span> mahsé hë phêk siam phalna hi i nei lo tlat thung.',
'userpage-userdoesnotexist' => 'Hmangtu siangchan "$1" hi hriat a ni lo.
He phêk hi siam/siamţhat emaw i duh chuan enfiah rawh.',
'userpage-userdoesnotexist-view' => 'Hmangtu siangchan "$1" hi hriat a ni lo.',
'blocked-notice-logextract' => 'He hmangtu hi danbeh hrih a ni.
I rawn atan a danbeh chhinchhiahna kan han tarlang a ni e:',
'usercssyoucanpreview' => "'''Rawlrûk:''' I CSS fiah tùrin i dahţhat hmain \"{{int:showpreview}}\" hmehkhep hi hmang rawh.",
'userjsyoucanpreview' => "'''Rawlrûk:''' I JavaScript thar fiah tùrin i dahţhat hmain \"{{int:showpreview}}\" hmehkhep hi hmang rawh.",
'updated' => '(Bithuam fel a ni)',
'note' => "'''Hriat tùr:'''",
'previewnote' => "'''Heihi endikna chauh a ni tih hrereng ang che.'''
I tihdanglamna dahţhat a la ni lo!",
'continue-editing' => 'Siamṭhat chhunzawmna',
'session_fail_preview_html' => "'''A pawi hlë mai! Ṭhutchhúng chanchin vawnna hloh avangin i siamṭhatna dahṭhat theih a ni lo.'''

''{{SITENAME}}-in HTML hel a tihzalen avangin hë enlâwkna hi JavaScript beihna laka invèn fimkhur nan thup bo a ni.''

'''Hei hi siamṭhat tumna dànzui pangngai a nih chuan khawngaihin dahṭhat tum nawn leh rawh.'''
I la dahṭhat theih loh cheu chuan [[Special:UserLogout|chhuah phawt ]] a, luh nawn leh hmang tein han bei vêl chhin lä.",
'editing' => '$1 i siamṭha mék',
'creating' => '$1 i siam mék',
'editingsection' => '$1 (hlawm) i siamṭha mék',
'editingcomment' => '$1 (hlawm thar) i siam mék',
'editconflict' => 'Siamţhat inchuh: $1',
'yourtext' => 'I thu tah hian:',
'storedversion' => 'Ennawnna vawnţhat',
'yourdiff' => 'Danglamnate',
'protectedpagewarning' => "'''Vaukhanna: Hë phêk hi roreltute chauhvin an siamṭhat theihna tùrin vènhim a ni.'''
I rawn atan ziaka chanchin dah hnuhnüng ber kan rawn chhawp chhuak e:",
'semiprotectedpagewarning' => "'''Hriat tùr:''' He phêk hi hmangtu inziaklûtte chauhvin an tihdanglam theih tùra vènhim a ni.
I ràwn tùrin siam danglamna chanchin ziaka kan dahţhat thạr ber a hnuaiah khuan kan rawn chhawpchhûak e:",
'templatesused' => 'He phêka {{PLURAL:$1|siamsa hman|siamsa hmante}}',
'templatesusedpreview' => 'He endiknaa {{PLURAL:$1|Siamsa hman|Siamsa hmante}}:',
'templatesusedsection' => 'Hemi hlawma  {{PLURAL:$1|Siamsa hman|Siamsa hmante}}',
'template-protected' => '(vènhim)',
'template-semiprotected' => '(hual)',
'hiddencategories' => 'He phêk hi {{PLURAL:$1| pawl thuhrûk 1|pawl thuhrûk $1}}-a tel a ni.',
'nocreate-loggedin' => 'Phêk thar siam phalna i nei lo.',
'sectioneditnotsupported-title' => 'Hlawm siamţhat bing theih loh',
'sectioneditnotsupported-text' => 'He phêkah hian hlawm siamţhat bing theih a ni lo.',
'permissionserrors' => 'Phalna dikhlel',
'permissionserrorstext' => 'He thil tih phalna hi i nei lo, a chhan{{PLURAL:$1||-te}} chu:',
'permissionserrorstext-withaction' => '$2: he thil tih phalna hi i nei lo, a chhan{{PLURAL:$1||-te}} chu:',
'recreate-moveddeleted-warn' => "'''Vaukhanna: A hmaa paih tawh phêk i thar thawh leh a.'''
He phêk buaipui chhunzawm hi a remchang nge chang lo tih inbihchiang rawh.
Remchangah he phek paihna leh sawnna chhinchhiahna-ziak rawn chhawp chhuah a ni e:",
'moveddeleted-notice' => 'He phek hi paih tawh a ni.
I rawn atan he phek paihna leh sawnna chanchin chhinchhiahna a hnuaiah khuan chhawp chhuah a ni.',
'log-fulllog' => 'Chanchin chhinchhiah kimchang hetah hian a en theih e.',
'edit-gone-missing' => 'Phêk bithuam theih a ni lo.
Nuaibo a ni tawh a nih hmèl.',
'edit-conflict' => 'Siamţhat inchuh buaina.',
'edit-no-change' => 'Tihdanglam i neih leh tâk loh avangin i siamṭhatna ngaihthah a ni.',
'edit-already-exists' => 'Phêk thar siam theih a ni lo.
A awm tawh sa.',
'defaultmessagetext' => 'Thuthawn tùr ziahsa',
'invalid-content-data' => 'Kentel phal loh thil',

# Content models
'content-model-wikitext' => 'wikithü',
'content-model-text' => 'thutluang',
'content-model-javascript' => 'JavaScript',
'content-model-css' => 'CSS',

# Parser/template warnings
'post-expand-template-inclusion-warning' => "'''Vaukhanna:''' Siamsa telh a lian leh lutuk.
Siamsa ţhenkhat hmaih a ni ang.",
'post-expand-template-inclusion-category' => 'Siamsa telh theih lenzawng khûmna phêkte',
'post-expand-template-argument-warning' => "'''Vaukhanna:''' He phekah hian siamsa kawng kaihparh theih lenzawng nei lian leh lutuk pakhat tal a awm a ni.
Heng kawngte hi hmaih mai tur.",
'post-expand-template-argument-category' => 'Siamsa kawng hmaih awmna phekte',
'parser-template-loop-warning' => 'Siamsa inthawnkual a awm tlat: [[$1]]',
'language-converter-depth-warning' => 'Ṭawng lehna thûkzawng pèl ($1)',
'node-count-exceeded-category' => 'Tihbawk theih chin pèl phêkte',
'node-count-exceeded-warning' => 'Suihbawl theih chin pèl phêkte',
'expansion-depth-exceeded-category' => 'Tihchiam theih chin pèl phêkte',
'expansion-depth-exceeded-warning' => 'Tihchiam theih chin phêkin a pèl',

# Account creation failure
'cantcreateaccounttitle' => 'Siangchan siam theih loh',

# History pages
'viewpagelogs' => 'He phêk chanchin hi en rawh',
'nohistory' => 'Hë phêk siamṭhatna chanchin ziak a awm lo tlat.',
'currentrev' => 'Ennawnna hnuhnung ber',
'currentrev-asof' => 'Dar $1-a ennawnna hnuhnung ber',
'revisionasof' => '$1 -a ennawnna zawng',
'revision-info' => '$1-a $2 ennawnna',
'previousrevision' => '←Ennawnna hlui zâwk',
'nextrevision' => 'Ennawnna thar zâwk →',
'currentrevisionlink' => 'Ennawnna hnuhnung ber',
'cur' => 'mék',
'next' => 'dawt',
'last' => 'hma',
'page_first' => 'hmasa ber',
'page_last' => 'tàwp ber',
'histlegend' => "Dnglmn thlanna: Ennawnna bawmte khu khaikhin tùrin klik rawh.
Lamtawi hmante: '''({{int:cur}})'''= ennawnna thar ber nena danglamna, '''({{int:last}})'''=ennawnna hmasa nena danglamna, '''{{int:minoreditletter}}'''= siamţhatna tenau.",
'history-fieldset-title' => 'Fanna chanchin',
'history-show-deleted' => 'Nuaibo tawh zawng chauh',
'histfirst' => 'Hmasa ber',
'histlast' => 'Hnuhnung ber',
'historysize' => '({{PLURAL:$1|bait 1 |bait $1}})',
'historyempty' => '(ruak)',

# Revision feed
'history-feed-title' => 'Ennawnna chanchin',
'history-feed-description' => 'Wiki-a hemi phêk ennawnna chanchin',
'history-feed-item-nocomment' => '$1-in $2-ah',

# Revision deletion
'rev-delundel' => 'tilang/thup',
'rev-showdeleted' => 'tihlanna',
'revdelete-show-file-submit' => 'Aw',
'revdelete-hide-restricted' => "Roreltute leh midangte paw'n an hmuh theih loh turin hriatna-taksa hi nuaibo rawh",
'revdelete-radio-set' => 'Aw',
'revdelete-radio-unset' => 'Aih',
'revdelete-log' => 'Chhan:',
'revdel-restore' => 'lang chin tihdanglamna',
'revdel-restore-deleted' => 'ennawnna nuaibo tawhte',
'revdel-restore-visible' => 'ennawn hmuh theih chin',
'pagehist' => 'Phêk chanchin',
'deletedhist' => 'Chanchin nuaibo',
'revdelete-reasonotherlist' => 'Chhan dang',
'revdelete-edit-reasonlist' => 'Nuaibona chhante siamṭhatna',
'revdelete-offender' => 'Ennawntu:',

# Suppression log
'suppressionlog' => 'Nuaibo chhinchhiahna',

# Merge log
'revertmerge' => 'Ţhenhranna',

# Diffs
'history-title' => '"$1" ennawnna chanchin',
'lineno' => 'Tlar $1:',
'compareselectedversions' => 'Ennawnna i thlan tâkte khaikhin rawh le',
'editundo' => 'tihletna',
'diff-multi' => '(Hmangtu {{PLURAL:$2|1-in|$2-ten}} a karlaka {{PLURAL:$2|a|an}} ennawnna {{PLURAL:$1|1|$1-te}} tihlan a ni lo)',

# Search results
'searchresults' => 'Zawn hmuhte',
'searchresults-title' => '"$1" tana zawn hmuhte',
'prevn' => 'hmasa {{PLURAL:$1|$1}}',
'nextn' => 'dawt {{PLURAL:$1|$1}}',
'prevn-title' => '{{PLURAL:$1|Zawnchhuah|Zawnchhuah}}  hmasa $1',
'nextn-title' => 'Zawnchhuah dawt leh $1 {{PLURAL:$1||}}',
'shown-title' => 'Phek khatah zawnchhuah $1 {{PLURAL:$1||}} zel tilang rawh',
'viewprevnext' => '($1 {{int:pipe-separator}} $2) ($3) en rawh',
'searchmenu-legend' => 'Zawn duhthlanna',
'searchmenu-exists' => "'''He wiki-ah hian \"[[:\$1]]\" tia koh phêk a awm.'''",
'searchmenu-new' => "'''[[:$1]] phek hi he wiki-ah hian siam rawh le!'''",
'searchmenu-prefix' => '[[Special:PrefixIndex/$1|He thuhmabet nei phêkte hi zawng rawh]]',
'searchprofile-articles' => 'A chhunga thu awm',
'searchprofile-project' => 'Ţanpuina leh hna-hmachhawp phekte',
'searchprofile-images' => 'Maltimedia',
'searchprofile-everything' => 'A vai',
'searchprofile-advanced' => 'Ràiril',
'searchprofile-articles-tooltip' => '$1-ah zawng rawh',
'searchprofile-project-tooltip' => '$1-ah zawng rawh',
'searchprofile-images-tooltip' => 'Taksa-ho zawnna',
'searchprofile-everything-tooltip' => 'A chhung zawng chhuak vek rawh (sawihona tiamin)',
'searchprofile-advanced-tooltip' => 'Hminghmun thlansa-ah zawng rawh',
'search-result-size' => '$1 ({{PLURAL:$2|Thumal 1 |Thumal $2 }})',
'search-result-category-size' => '{{PLURAL:$1|Tel 1 |Tel $1 }} ({{PLURAL:$2|Pawlpéng 1 |Pawlpéng $2}}, {{PLURAL:$3|Taksa 1 |Taksa $3 f}})',
'search-result-score' => 'Intûkna: $1%',
'search-redirect' => '($1 aţanga hruailuh)',
'search-section' => '(hlawm $1)',
'search-suggest' => '$1 i tihna a ni a ni zawk em?',
'search-interwiki-caption' => 'Hmachhawppuite',
'search-interwiki-default' => 'Chhuak $1:',
'search-interwiki-more' => '(tam)',
'search-relatedarticle' => 'Laichin',
'mwsuggest-disable' => 'AJAX rawtna tithi rawh',
'searcheverything-enable' => 'Hminghmun zawng zawngah zawng rawh',
'searchrelated' => 'laichin',
'searchall' => 'a vaiin',
'showingresultsheader' => "'''$4'''  tana {{PLURAL:$5|chhuak   '''$3'''  zinga  '''$1'''|chhuak  '''$3'''  zinga   '''$1 - $2'''  }}",
'search-nonefound' => 'I zawn mil a awm lo',
'powersearch' => 'Zawnna chi sang',
'powersearch-legend' => 'Zawnna chi sang',
'powersearch-ns' => 'Hemi hminghmun chhungah hian zawng rawh:',
'powersearch-redir' => 'Thawnkual ngaiho',
'powersearch-field' => 'Hei hi zawng rawh:',
'powersearch-togglelabel' => 'Thai rawh:',
'powersearch-toggleall' => 'A vaiin',
'powersearch-togglenone' => 'Pakhat mah',
'search-external' => 'Pawnlam zawnna',
'searchdisabled' => '{{SITENAME}} zawnna tihthih a ni.
Google hmangin i lo zawng hrih thei ang.
{{SITENAME}} chhung zawnawlna hi a hlui lutuk tawh mai thei tih hria ang che.',

# Preferences page
'preferences' => 'Duhdàn',
'mypreferences' => 'Duhthlanna',
'prefs-edits' => 'Siamţhat zât',
'prefsnologin' => 'I la lût lo',
'prefsnologintext' => 'Hmangtu duhdàn siam tùrin i <span class="plainlinks"> [{{fullurl:{{#Special:UserLogin}}|returnto=$1}} inziah luh] </span> a ngai.',
'changepassword' => 'Thurûk thlâkna',
'prefs-skin' => 'Vun',
'skin-preview' => 'Enchhinna',
'datedefault' => 'Duhdàn awm lo',
'prefs-beta' => 'Beta hman theihnate',
'prefs-datetime' => 'Hun leh ni',
'prefs-labs' => '"Lab" hman theihnate',
'prefs-user-pages' => 'Hmangtu phêkte',
'prefs-personal' => 'Hmangtu chanchin tawi',
'prefs-rc' => 'Tihdanglam thar',
'prefs-watchlist' => 'Ralvèn',
'prefs-watchlist-days' => 'Ralvèna ni tihlan tùr chin:',
'prefs-watchlist-days-max' => 'A rei berah ni $1 {{PLURAL:$1||}}',
'prefs-watchlist-edits' => 'Ralvèn pawhseia tihdanglam zât tihlan tùr tam ber:',
'prefs-watchlist-edits-max' => 'A tam ber: 1000',
'prefs-watchlist-token' => 'Ralvèn chhinchhiahrelh:',
'prefs-misc' => 'Neuh neuh dang',
'prefs-resetpass' => 'Thurûk thlâkna',
'prefs-changeemail' => 'E-chenhmun thlâk rawh',
'prefs-setemail' => 'E-chenhmun ziak rawh',
'prefs-email' => 'E-chenhmuh duhdàn',
'prefs-rendering' => 'Landàn',
'saveprefs' => 'Dahţhatna',
'resetprefs' => 'Tihdanglamna dahţhat loh tifai rawh',
'restoreprefs' => 'A awmdàn siamsaah dah lêt vek rawh',
'prefs-editing' => 'Siamţhat',
'rows' => 'Tlar:',
'columns' => 'Thlur:',
'searchresultshead' => 'Zawnna',
'resultsperpage' => 'Phêk khat tawh zât:',
'stub-threshold-disabled' => 'Tihnun a ni lo',
'recentchangesdays' => 'Tihdanglam thar ni tihlan tùr chin:',
'recentchangesdays-max' => 'A tam berah ni $1 {{PLURAL:$1||}}',
'recentchangescount' => 'Siamţhat tihlan ziah tùr zât:',
'prefs-help-recentchangescount' => 'Hei hian tihdanglam thar, phêk chanchin leh tihdanglam a nihdàn a keng tel.',
'savedprefs' => 'I duhdàn dahţhat a ni ta.',
'timezonelegend' => 'Hun-bial:',
'localtime' => 'Tualchhung hun:',
'timezoneuseserverdefault' => 'Wiki ($1) hi hmang rawh',
'timezoneuseoffset' => 'A dang (sawi chiang la)',
'timezoneoffset' => 'Darkar inthlauhna:',
'servertime' => 'Server hun:',
'guesstimezone' => 'Rangpuifanna aţang dahkhat rawh',
'timezoneregion-africa' => 'Afrika',
'timezoneregion-america' => 'Amerika',
'timezoneregion-antarctica' => 'Antarktika',
'timezoneregion-arctic' => 'Arktik',
'timezoneregion-asia' => 'Asia',
'timezoneregion-atlantic' => 'Atlantik tuifinriat',
'timezoneregion-australia' => 'Australia',
'timezoneregion-europe' => 'Iurawp',
'timezoneregion-indian' => 'India tuifinriat',
'timezoneregion-pacific' => 'Tuifinriat dam',
'allowemail' => 'Hmangtu dang e-lehkhathawn phal rawh',
'prefs-searchoptions' => 'Zawn duhthlanna',
'prefs-namespaces' => 'Hminghmun',
'defaultns' => 'A nih loh vëk leh hêng hminghmunahte hian zawng rawh:',
'default' => 'thlansa',
'prefs-files' => 'Taksa',
'prefs-custom-css' => 'CSS hman',
'prefs-custom-js' => 'JavaScript hman',
'prefs-common-css-js' => 'CSS inţawm/vun zawng zawng tana JavaScript',
'prefs-reset-intro' => 'He phêk hi ränghmuna i duhthlansa tihdanglam nan i hmang thei.
A sûtlêt theih loh.',
'prefs-emailconfirm-label' => 'E-chenhmun tihchianna:',
'youremail' => 'E-chenhmun:',
'username' => 'Hmangtu hming:',
'uid' => 'Hmangtu ID',
'prefs-memberingroups' => '{{PLURAL:$1|pawl|pawlte}}-a tel.',
'prefs-registration' => 'Inziahluh hun:',
'yourrealname' => 'Hming tak:',
'yourlanguage' => 'Ţawng:',
'yourvariant' => 'Ţawng hman dang:',
'prefs-help-variant' => 'Wiki phêk pholanna duhthlan.',
'yournick' => 'Hmingtàr thar:',
'prefs-help-signature' => '"<nowiki>~~~~</nowiki>" tih i chhutna apiangah i hmingtàr leh hun a inziak zël ang.',
'badsig' => 'Hmingtàr dik lo.
HTML chhinchhiahna enfiah rawh.',
'badsiglength' => 'I hmingtàr a sei lutuk.
Hawrawp $1 {{PLURAL:$1||}} aiin a sei tùr a ni lo.',
'yourgender' => 'Mipa/Hmeichhia:',
'gender-unknown' => 'Thup',
'gender-male' => 'Mipa',
'gender-female' => 'Hmeichhia',
'prefs-help-gender' => 'Hmaih awih: Khawlthluakin ka pu tih tùr nge ka pi tih tùr a hriat theih nan.
Hei erawh hi chu tàrlan a ni ang (vantlang hmuh theihin).',
'email' => 'E-chenhmun',
'prefs-help-realname' => 'Hming tak hi hmaih thiang.
I hming tak ziahlan i duh chuan i hnaa chawimawina iloah hman a ni ang.',
'prefs-help-email' => 'E-chenhmun hi hmaih awih a ni a, mahsé i thurûk ilo i theihnghilh palhin hman a ţul ang.',
'prefs-help-email-others' => 'I hmangtu sawihona phêkah hmangtu dangte e-lehkha i inthawntir thei bawk ang i duh chuan.
Hmangtuten e-lehkha an thawn chein i e-chenhmun hrilh an ni chuang lo vang.',
'prefs-help-email-required' => 'E-chenhmun ziah ngei ngei a ngai.',
'prefs-info' => 'Chanchin tlanglawn',
'prefs-i18n' => 'Khawvel-mil-a-herremna',
'prefs-signature' => 'Hmingtàr',
'prefs-dateformat' => 'Hun tarlan dan tùr',
'prefs-timeoffset' => 'Hun inthlauhna',
'prefs-advancedediting' => 'Duhthlan ràiril',
'prefs-advancedrc' => 'Duhthlan ràiril',
'prefs-advancedrendering' => 'Duhthlan ràiril',
'prefs-advancedsearchoptions' => 'Duhthlan ràiril',
'prefs-advancedwatchlist' => 'Duhthlan ràiril',
'prefs-displayrc' => 'Duhthlanna tilang rawh',
'prefs-displaysearchoptions' => 'Duhthlanna tilang rawh',
'prefs-displaywatchlist' => 'Duhthlanna tilang rawh',
'prefs-diffs' => 'Danglamna',

# User preference: email validation using jQuery
'email-address-validity-valid' => 'E-chenhmun a dik hmel',
'email-address-validity-invalid' => 'E-chenhmun dik ziak rawh',

# User rights
'userrights' => 'Hmangtu dikna-chanvo enkawlna',
'userrights-lookup-user' => 'Hmangtu pawl enkawl rawh',
'userrights-user-editname' => 'Hmangtu hming ziak rawh:',
'editusergroup' => 'Hmangtu pawl siamţha rawh',
'editinguser' => "Hmangtu '''[[User:$1|$1]]''' dikna-chanvo siamţhatna: $2",
'userrights-editusergroup' => 'Hmangtu pawl siamţha rawh',
'saveusergroups' => 'Hmangtu pawl dahţha rawh',
'userrights-groupsmember' => 'Telna pawl:',
'userrights-groupsmember-auto' => 'Telsana pawl:',
'userrights-reason' => 'Chhan:',
'userrights-no-interwiki' => 'Wiki dangah hmangtute dikna-chanvo siam danglam theihna phalna i nei lo.',
'userrights-nodatabase' => 'Database $1 a awm lo a nih loh pawhin khawtual thil a nih loh hmel.',
'userrights-nologin' => 'Hmangtu dikna-chanvo bithliah thei tùr chuan roreltu siangchanin i [[Special:UserLogin| luh]] a ngai.',
'userrights-notallowed' => 'I siangchanin hmangtu dikna-chanvo belh leh paih theihna phalna a nei lo.',
'userrights-changeable-col' => 'I thlâk theih pawlte',
'userrights-unchangeable-col' => 'I thlâk theih loh pawlte',

# Groups
'group' => 'Pawl:',
'group-user' => 'Hmangtute',
'group-autoconfirmed' => 'Infinfiahsa hmangtute',
'group-bot' => 'Khawlmite',
'group-sysop' => 'Roreltute',
'group-bureaucrat' => 'Khawnbawlho',
'group-suppress' => 'Viltute',
'group-all' => '(a vaiin)',

'group-user-member' => 'Hmangtu {{GENDER:$1|}}',
'group-autoconfirmed-member' => '{{GENDER:$1|Infinfiahsa hmangtu}}',
'group-bot-member' => 'Khawlmi {{GENDER:$1|}}',
'group-sysop-member' => 'Roreltu {{GENDER:$1|}}',
'group-bureaucrat-member' => 'Khawnbawl {{GENDER:$1|}}',
'group-suppress-member' => 'Viltu {{GENDER:$1|}}',

'grouppage-user' => '{{ns:project}}:Hmangtute',
'grouppage-autoconfirmed' => '{{ns:project}}:Infiahsa hmangtute',
'grouppage-bot' => '{{ns:project}}:Khawlmite',
'grouppage-sysop' => '{{ns:project}}:Roreltute',
'grouppage-bureaucrat' => '{{ns:project}}:Khawnbawlte',
'grouppage-suppress' => '{{ns:project}}:Viltute',

# Rights
'right-read' => 'Heng phêkte hi chhiar rawh',
'right-edit' => 'Heng phêkte hi siamţha rawh',
'right-createpage' => 'Heng phêkte hi siam rawh (sawihona phêk ni lovin)',
'right-createtalk' => 'Sawihona phêk siam rawh',
'right-createaccount' => 'Hmangtu siangchan thar siam rawh',
'right-minoredit' => 'Siamţhat tenau angin chhinchhiah rawh',
'right-move' => 'Phêk sawnna',
'right-move-subpages' => 'Phêkte leh an phêkpéngte sawnna',
'right-move-rootuserpages' => 'Hmangtu bulte sawnna',
'right-movefile' => 'Taksa sawnna',
'right-suppressredirect' => 'Phêk sawna hruailuhna phêk siam lohtírna',
'right-upload' => 'Taksa hlankaina',
'right-reupload' => 'Taksa awmsa ziahhnan rawh',
'right-reupload-own' => 'Mahni hlankai taksa awmsa ziahhnan rawh',
'right-upload_by_url' => 'URL hmangin taksa hlangkai rawh',
'right-autoconfirmed' => 'Phêk vèn-chanve-ho siamţha rawh',
'right-bot' => 'Khawl hnathawha ngaih ni rawh',
'right-delete' => 'Heng phêkte hi nuaibo/paih rawh',
'right-bigdelete' => 'Phêk chanchin ngah lutuk nuaibo rawh',
'right-browsearchive' => 'Phêk nuaibo tawh zawng lêt leh rawh',
'right-undelete' => 'Phêk nuaibo sût lêt rawh',
'right-suppressionlog' => 'Mahni chanchin tawi enna',
'right-block' => 'Hmangtu dangin an siam danglam tùr veng rawh',
'right-blockemail' => 'Hmangtu e-lehkha thawn tùr dang rawh',
'right-hideuser' => 'Hmangtu hming dangbet rawh, vantlang laka thupin',
'right-unblockself' => 'Mahnia dalna inphelh',

# Special:Log/newusers
'newuserlogpage' => 'Hmangtu siamna chanchin-ziak',
'newuserlogpagetext' => 'Hei hi hmangtu siangchan siam chhinchhiahna a ni.',

# Associated actions - in the sentence "You do not have permission to X"
'action-read' => 'he phêk hi chhiar rawh',
'action-edit' => 'phek siamṭhat',
'action-createpage' => 'phêk siam tharna',
'action-createtalk' => 'sawihona phêk siamna',
'action-createaccount' => 'he hmangtu siangchan hi siam rawh',
'action-minoredit' => 'siamţhat tenauah chhiar rawh',
'action-move' => 'he phêk hi sawn rawh',
'action-move-subpages' => 'he phêk leh a phêkpéngte hi sawn rawh',
'action-move-rootuserpages' => 'hmangtu bul phêk sawnna',
'action-movefile' => 'taksa sawnna',
'action-upload' => 'he taksa hi hlangkai rawh',
'action-reupload' => 'taksa awmsa luahlantir rawh',
'action-upload_by_url' => 'URL aţang he taksa hi hlangkai rawh',
'action-writeapi' => 'ziakna WPI hmang rawh',
'action-delete' => 'he phêk hi paih rawh',
'action-deleterevision' => 'he ennawnna hi paih rawh',
'action-deletedhistory' => 'phêk chanchin nuaibo tawh enna',
'action-browsearchive' => 'phêk nuaibo tawhte zawng rawh',
'action-undelete' => 'he phêk hi lakir leh rawh',
'action-suppressionlog' => 'mimal chanchin bîk enna',
'action-block' => 'he hmangtuina a siam danglam tùr hi däl rawh',

# Recent changes
'nchanges' => 'Tihdanglam {{PLURAL:$1||$1-te}}',
'recentchanges' => 'Tihdanglam thar',
'recentchanges-legend' => 'Tihdanglam thar duhdàn',
'recentchanges-summary' => 'He phek wiki-a tihdanglamna thar deuh deuhte chhui rawh.',
'recentchanges-feed-description' => 'He chawm-a wiki tihdanglamna thar deuh deuhte chhui rawh.',
'recentchanges-label-newpage' => 'Hei hi phêk thar siamna a ni.',
'recentchanges-label-minor' => 'Hei hi siamţhatna tenau a ni',
'recentchanges-label-bot' => 'He siamţhat hi khawlmi tih a ni',
'recentchanges-label-unpatrolled' => 'He siamţhat hi viltu la nei lo a ni',
'rcnote' => "Ni $4, dar $5-a a landàna ni {{PLURAL:$2|khat|'''$2'''}} kaltaa tihdanglamna {{PLURAL:$1|'''1'''|thar ber ber '''$1'''}} a hnuaiah khuan kan rawn chhawp chhuak e.",
'rcnotefrom' => "'''$2''' hnua tihdanglamna zawng zawng a hnuaiah khuan kan rawn tilang e ('''$1''' thleng chauh tihlan a ni).",
'rclistfrom' => '$1 hnu lama tihdanglama tihlanna',
'rcshowhideminor' => 'siamţhat tenau $1',
'rcshowhidebots' => 'Khawlmi $1',
'rcshowhideliu' => 'hmangtu inziaklut $1',
'rcshowhideanons' => 'hming hriat loh $1',
'rcshowhidepatr' => 'siamthat vil $1',
'rcshowhidemine' => 'ka siamţhat $1',
'rclinks' => 'Ni $2 kaltaa tihdanglamna hnuhnung $1 tihlanna<br /> $3.',
'diff' => 'dnglmn',
'hist' => 'chanchin',
'hide' => 'Tihbona',
'show' => 'Tihlanna',
'minoreditletter' => 't',
'newpageletter' => 'T',
'boteditletter' => 'k',
'number_of_watching_users_pageview' => '[$1 hmangtu {{PLURAL:$1||te}} vil mék]',
'rc_categories' => 'Pawla bithliahna ("|" hmangin kárdan rawh)',
'rc_categories_any' => 'Väi',
'rc-change-size-new' => 'Tihdanglam hnuah {{PLURAL:$1|bait|bait}} $1',
'newsectionsummary' => '/* $1 */ hläwm thar',
'rc-enhanced-expand' => 'Tilang kim rawh (JavaScript a ngai)',
'rc-enhanced-hide' => 'Thup ţhenna',
'rc-old-title' => 'Atìra "&1" tih hming pú-a siam.',

# Recent changes linked
'recentchangeslinked' => 'Tihdanglam anpuite',
'recentchangeslinked-feed' => 'Tihdanglam anpuite',
'recentchangeslinked-toolbox' => 'Tihdanglam anpuite',
'recentchangeslinked-title' => '"$1" kaihhnawih tihdanglamnate',
'recentchangeslinked-summary' => "Hei hi phek pakhat (emaw pawl pakhata telte) aţanga zawm chhuah phek-hova tihdanglam thar ziah chhuahna a ni.
[[Special:Watchlist|I ralvèn]] phêkte chu '''hawrawp thau'''-a tihlan a ni.",
'recentchangeslinked-page' => 'Phek hming:',
'recentchangeslinked-to' => 'Phek peksaa zawm phekte tihdanglamnate tilang zawk rawh',

# Upload
'upload' => 'Taksa hlankaina',
'uploadbtn' => 'Taksa hlankaina',
'reuploaddesc' => 'Hlankai ţhulh la hlankaina hmunah kir leh rawh',
'upload-tryagain' => 'Taksa sawifiahna siam danglam thehlut rawh',
'uploadnologin' => 'I la lût lo',
'uploadnologintext' => 'Taksa hlangkai tùrin i [[Special:UserLogin|inziahluh]] ngei ngei a ngai.',
'upload_directory_missing' => 'Hlankai bawmpui ($1)  a awm lo va, Rangserverin a siam thei lo bawl.',
'upload_directory_read_only' => 'Hlankai bawmpui ($1) hi Rangserver in a ziak thei lo.',
'uploaderror' => 'Hlankai sual',
'upload-recreate-warning' => "'''Vaukhànna: Hemi hming pu taksa hi sawn tawh emaw paih tawh a ni.'''

I ràwnah paihna leh sawnna chhinchhiahna thuziak kan rawn chhawpchhuak e:",
'uploadtext' => "Taksa hlankai nan a hnuaia lehkha hi hmang rawh.
Ahmaa taksa hlankaisaho en tùr emaw zawng tùr chuan [[Special:FileList|taksa hlankai tawh zawng zawng tlarna]] tihah hian kal rawh; hlankai (nawn)ho pawh [[Special:Log/upload|hlankai chhinchhiahna]]-ah vawnfel an ni a, paih tawhho pawh [[Special:Log/delete|paihho chhinchhiahna]]-ah chhinchhiah fel vek an ni.

Phêka taksa hmang tùrin ahnuaia tihphung engemaw ni ber hmang khuan zawmna i siam thei ang:
*A taksa pumpui hmang tùr chuan '''<code><nowiki>[[</nowiki>{{ns:file}}<nowiki>:File.jpg]]</nowiki></code>''' tiin. Heti hi chuan taksa hi i sezawl chhuah a ni.
*Phêk veilam síra 'Sawifiahna' hmanga 200px-a liana i tàrlan duh chuan '''<code><nowiki>[[</nowiki>{{ns:file}}<nowiki>:File.png|200px|thumb|left|Sawifiahna]]</nowiki></code>'''  tiin.
*A taksa tárlang lova zawm ringawt i duh chuan '''<code><nowiki>[[</nowiki>{{ns:media}}<nowiki>:File.ogg]]</nowiki></code>''' tiin.",
'upload-permitted' => 'Taksa phal chiho: $1.',
'upload-preferred' => 'Taksa duh deuh bîk: $1.',
'upload-prohibited' => 'Taksa khap: $1.',
'uploadlog' => 'hlankai chhinchhiahna',
'uploadlogpage' => 'Hlankai chhinchhiahna',
'uploadlogpagetext' => 'Taksa hlankai thar deuh deuh kan rawn tlar chhuak e.
A aia hmuhnawm deuh zâwka i thlìr duh chuan [[Special:NewFiles|taksa hlankai thar tàrhmunpui]]-ah i kal thei ang.',
'filename' => 'Taksahming',
'filedesc' => 'Sawifiahna täwi',
'fileuploadsummary' => 'Sawifiahna täwi:',
'filereuploadsummary' => 'Taksa tihdanglamna:',
'filestatus' => 'Lâkchhàwn phalphung dinhmun:',
'filesource' => 'Hnar:',
'uploadedfiles' => 'Taksa hlankai tawhte',
'ignorewarning' => 'Vaukhanna ngaihthah la taksa dahţha lui rawh',
'ignorewarnings' => 'Vaukhanna zawng zawng ngaihthah vek rawh',
'minlength1' => 'Taksahming reng reng hawrawp pakhat tala sei a ni tur a ni.',
'illegalfilename' => 'Taksahming "$1"-in hawrawp phal loh a kengtel.
A hming thlâk la bei ţha leh rawh.',
'filename-toolong' => 'Taksahming 240 bytes aiin a sei tùr a ni lo.',
'badfilename' => 'Taksahming "$1"-ah thlâk a ni.',
'filetype-mime-mismatch' => 'Taksa hming zauhna ".$1"-in a taksa MIME chî kan hmuh ($2) a mil lo tlat.',
'filetype-badmime' => '"$1" ang MIME chî taksa hlànkài phal a ni lo.',
'filetype-unwanted-type' => "'''\".\$1\"''' hi taksa phal loh chî a ni.
Taksa phalzáwng{{PLURAL:\$3||te}} chu: \$2.",
'filetype-missing' => 'Taksain tawpna a nei lo (entirna ".jpg").',
'empty-file' => 'I taksa thehluh kha a ruak.',
'file-too-large' => 'A lian leh lutuk.',
'filename-tooshort' => 'Taksahming a sawi leh lutuk.',
'filetype-banned' => 'Hetiang taksa hi khap a ni.',
'verification-error' => 'Finfiah loh.',
'hookaborted' => 'Tawpna-in a tikhaihlak.',
'illegal-filename' => 'Taksahming phal loh.',
'overwrite' => 'Taksa awmsa ziah hnan khap a ni.',
'unknown-error' => 'Dikhlelhna hriat loh a lo thleng.',
'tmp-create-error' => 'Taksa lailâwk a siam theih loh.',
'tmp-write-error' => 'Taksa lailâwk ziah a tlawlh',
'large-file' => 'Taksa rëng rëng $1 aia lian lo tùra duh a ni;
he taksa hi $2 lái a ni.',
'largefileserver' => 'Hë taksa hi rawngbawltu phaltir zât aia ritsak a ni.',
'windows-nonascii-filename' => 'Hë wiki hian taksahminga chhinchhiahna bîk tel a pawm thei lo.',
'savefile' => 'Taksa dahṭhatna',
'uploadedimage' => 'hlankai: "[[$1]]"',
'uploadvirus' => 'I taksa hlànkài tumin hrik a päi!
Chanchin kimchang: $1',
'upload-source' => 'Hnar taksa',
'sourcefilename' => 'Hnar taksahming:',
'sourceurl' => 'Hnar URL:',
'destfilename' => 'Tumhmun taksahming:',
'upload-maxfilesize' => 'Taksa lenzáwng bituk: $1 aia lian lo.',
'upload-description' => 'Taksa sawifiahna',
'upload-options' => 'Hlankai duhdàn thlanna',
'watchthisupload' => 'Hë taksa hi vil rawh',
'filewasdeleted' => 'He hming pu taksa hi ahmaah lo hlankai tawh a ni a, paihbo leh nghâl a ni.
Hlankai leh i tum hmain $1 i thlïthläi deuh dawn nia.',
'upload-success-subj' => 'Hlawhtling taka hlankai a ni',
'upload-success-msg' => '[$2] aṭangin i hlangkai hlawhtling ta e. Hetah hian hman theihin a awm ta: [[:{{ns:file}}:$1]]',
'upload-failure-subj' => 'Hlankai rokhawlhna',
'upload-failure-msg' => '[$2] aṭanga i hlankai tumnaah rokhawlhna a awm tlat:

$1',
'upload-warning-subj' => 'Hlankai vauhkhànna',
'upload-warning-msg' => '[$2] aṭanga i hlankaiah rokhawlhna a awm tlat. [[Special:Upload/stash/$1|Hlankaina lehkha]]-ah chingfel tùrin i lêt leh thei ang.',

'upload-proto-error' => 'Inpawhphung dikhlel',
'upload-file-error' => 'Chhúnglam dik lohna',

'license' => 'Phalphung:',
'license-header' => 'Phalphung:',
'nolicense' => 'I la thlang lo',
'license-nopreview' => '(Endik chhin theih loh)',
'upload_source_url' => '(URL tláng pawh theih, nung bawk)',
'upload_source_file' => '(i khawlthlûakneia mi taksa)',

# Special:ListFiles
'listfiles-summary' => 'Hë vohbîk phêk hian taksa hlankai tawh zawng zawng a pholang.
Hmangtu azira i thliarhran erawh chuan a hmangtuina a hlankai hnuhnüng ber taksa chauh pholan a ni.',
'listfiles_search_for' => 'Media hming zawnna:',
'imgfile' => 'taksa',
'listfiles' => 'Taksa tlarna',
'listfiles_thumb' => 'Kutbï',
'listfiles_date' => 'Ni',
'listfiles_name' => 'Hming',
'listfiles_user' => 'Hmangtu',
'listfiles_size' => 'Lenzawng',
'listfiles_description' => 'Sawifiahna',
'listfiles_count' => 'Chhuah',

# File description page
'file-anchor-link' => 'Taksa',
'filehist' => 'Hunhlui-chanchin',
'filehist-help' => 'A hunlaia a lan dan en tùrin a hun/ni-ah hmet rawh.',
'filehist-deleteall' => 'a vaiin nuaibo rawh',
'filehist-deleteone' => 'nuaibo rawh',
'filehist-revert' => 'tihlêtna',
'filehist-current' => 'mék',
'filehist-datetime' => 'Ni/Hun',
'filehist-thumb' => 'Kutbï',
'filehist-thumbtext' => '$1 chhuah kutbï',
'filehist-nothumb' => 'Kutbï awm lo',
'filehist-user' => 'Hmangtu',
'filehist-dimensions' => 'Lenzawng',
'filehist-filesize' => 'A lenzawng',
'filehist-comment' => 'Tuihnihna',
'filehist-missing' => 'Taksa a awm lo',
'imagelinks' => 'Bungraw hmanna',
'linkstoimage' => 'A hnuai  {{PLURAL:$1|phek 1|phek $1-te}} hian he taksa hi a hmang:',
'linkstoimage-more' => 'Hë taksa hi phêk {{PLURAL:$1||}} $1 aia tamin a zawm/hmang.
Ahnuaih hian {{PLURAL:$1|zawmtu hmasa ber|zawmtu hmasa $1-te}} kan rawn tlar chhuak e.
Zawmtu zawng zawng [[Special:WhatLinksHere/$2|tlarchhuahna hetah hian a awm]] e.',
'nolinkstoimage' => 'He taksa zawmtu/hmanna phêk pakhat mah a awm lo.',
'morelinkstoimage' => 'Hemi taksa zawmpui dang [[Special:WhatLinksHere/$1|enna]].',
'linkstoimage-redirect' => '$1 (taksa hruailuhna) $2',
'duplicatesoffile' => 'A hnuaia taksa{{PLURAL:$1||te}} khu hë taksa nihpui{{PLURAL:$1||te}} a{{PLURAL:$1||n}} ni ([[Special:FileDuplicateSearch/$2|chanchin kimchang]]):',
'sharedupload' => 'Hë taksa hi $1-a mi a ni a, hna-hmachhawp dangin a hmang vè mai thei.',
'sharedupload-desc-there' => 'Hë taksa hi $1-a mi a ni a, hna-hmachhawp dangin a hmang ve mai thei.
Hriattirna dang chu [$2 taksa sawifiahna phêk]-ah hian i en thei ang.',
'sharedupload-desc-here' => 'He taksa hi $1-a mi a ni a, hna-hmachhawp dangin an hmang ve mai thei.
[$2 Taksa sawifiahna phek]-a sawifiahna lang hetah hian kan rawh chhawp chhuak e.',
'sharedupload-desc-edit' => 'Hë taksa hi $1-a mi a ni a, hna-hmachhawp dangin a hmang vè mai thei.
Taksa sawifiahna hi i siamṭha duh a nih chuan  [$2 taksa sawifiahna phêk] aṭang hian i siamṭha thei ang.',
'sharedupload-desc-create' => 'Hë taksa hi $1-a mi a ni a, hna-hmachhawp dangin a hmang vè mai thei.
Taksa sawifiahna hi i siamṭha duh a nih chuan  [$2 taksa sawifiahna phêk] aṭang hian i siamṭha thei ang.',
'filepage-nofile' => 'He hmingpu taksa a awm lo',
'filepage-nofile-link' => 'He hming pu taksa hi a awm lo va, mahsé i [$1 hlangkai thei] ang.',
'uploadnewversion-linktext' => 'He taksa chhuah thar hi hlangkai rawh',
'shared-repo-from' => '$1 aţang',
'shared-repo' => 'chhêk-in inţawm',

# File reversion
'filerevert' => '$1 tilêt rawh',
'filerevert-legend' => 'Taksa tilêt rawh',

# MIME search
'mimetype' => 'MIME chî:',
'download' => 'hnuhthlâkna',

# Unwatched pages
'unwatchedpages' => 'Vèn loh phêkte',

# List redirects
'listredirects' => 'Hruailuhna phêkte',

# Unused templates
'unusedtemplates' => 'Siamsa hman lohte',
'unusedtemplateswlh' => 'zawmna dang',

# Random page
'randompage' => 'Phêk kahpah',
'randompage-nopages' => "{{PLURAL:$2|Hë hminghmunah hian|Hê'ng hminghmunahte hian}} phêk pakhat mah a awm lo: $1.",

# Random redirect
'randomredirect' => 'Hruailuhna kahpah',
'randomredirect-nopages' => '"$1" hminghmunah hian hruailuhna phêk pakhat mah a awm lo.',

# Statistics
'statistics' => 'Lepsena',
'statistics-header-pages' => 'Phêk lepsena',
'statistics-header-edits' => 'Siamṭhatphung lepsena',
'statistics-header-views' => 'Tlawhna lepsèna',
'statistics-header-users' => 'Hmangtute chanchin kimchang',
'statistics-header-hooks' => 'Chanchin dang',
'statistics-articles' => 'Thuziakna phêkte',
'statistics-pages' => 'Phekte',
'statistics-pages-desc' => 'Hë wiki-a phêk awm zawng zawng, sawihona phêk, hruailuhna phêk ladt. tel vekin.',
'statistics-files' => 'Taksa hlankaite',
'statistics-edits' => '{{SITENAME}} din achina phêk khawih danglam zât',
'statistics-edits-average' => 'Phêk khat zëla siamṭhat zât chawhrual',
'statistics-views-total' => 'Tlawh zât',
'statistics-views-total-desc' => 'Phêk awm lo leh phêk vohbîkte tlawhna chu chhiar tel a ni lo',
'statistics-views-peredit' => 'Siamṭhat pakhat zël tlawh zât',
'statistics-users' => '[[Special:ListUsers|Hmangtu]] inziaklût zât',
'statistics-users-active' => 'Hmangtu aktif zât',
'statistics-users-active-desc' => 'Ni {{PLURAL:$1|khat|$1}} kaltâ chhunga thiltih nei hmangtuho',
'statistics-mostpopular' => 'Phêk thlir zin deuh deuhte',

'doubleredirects' => 'Hruailuhna phír',
'double-redirect-fixed-move' => '[[$1]] sawn a ni ta.
[[$2]] lama hruailuhna siam nghâl a ni.',
'double-redirect-fixed-maintenance' => '[[$1]] aṭanga [[$2]] hruailuhna phír chinfel.',
'double-redirect-fixer' => 'Hruailuhna chingfeltu',

'brokenredirects' => 'Hruailuhna kehchhia',
'brokenredirectstext' => 'Ahnuaia hruailuhnate hian phêk awm lova hruailuh an tum:',
'brokenredirects-edit' => 'siamţhatna',
'brokenredirects-delete' => 'paihna',

'withoutinterwiki-legend' => 'Thuhmabet',
'withoutinterwiki-submit' => 'Tihlanna',

'fewestrevisions' => 'Phêk siam danglam hlawh lo zualte',

# Miscellaneous special pages
'nbytes' => 'Bait {{PLURAL:$1||}} $1',
'ncategories' => '{{PLURAL:$1|Páwl|Páwl}} $1',
'nlinks' => '$1 {{PLURAL:$1||}} Zawmna $1',
'nmembers' => 'A chhungah  {{PLURAL:$1||$1}} a awm.',
'nrevisions' => 'siamṭhatna $1 {{PLURAL:$1||}}',
'nviews' => 'vawi $1 {{PLURAL:$1||}} ràwn a ni tawh.',
'nimagelinks' => 'Phêk $1-ah {{PLURAL:$1||}} hman a ni.',
'ntransclusions' => 'phêk $1-ah {{PLURAL:$1||}} hman a ni.',
'specialpage-empty' => 'Thuhawn a awm lo tlat.',
'lonelypages' => 'Phêk fahrahte',
'uncategorizedpages' => 'Páwl nei lo phêkte',
'uncategorizedcategories' => 'Páwl nei lo páwlte',
'uncategorizedimages' => 'Páwl nei lo taksate',
'uncategorizedtemplates' => 'Páwl nei lo siamsâte',
'unusedcategories' => 'Páwl hman lohte',
'unusedimages' => 'Taksa hman hlawh lote',
'popularpages' => 'Phêk lärte',
'wantedcategories' => 'Páwl mamawhte',
'wantedpages' => 'Phêk mamawhte',
'wantedpages-badtitle' => 'Phêk hming dik lo: $1',
'wantedfiles' => 'Taksa mamawhte',
'wantedtemplates' => 'Siamsa mamawhte',
'mostlinked' => 'Phêk zawm hlawh berte',
'mostlinkedcategories' => 'Pawl zawm hlawh berte',
'mostlinkedtemplates' => 'Siamsa hman hlawh berte',
'mostcategories' => 'Telna páwl ngah ber phêkte',
'mostimages' => 'Taksa hman hlawh berte',
'mostrevisions' => 'Phêk siam danglam zin berte',
'prefixindex' => 'Hemi hmabet nei phek zawng zawng',
'prefixindex-namespace' => 'Hemi ($1 hminghmun) hmabeta neih phêk zawng zawngte',
'shortpages' => 'Phêk täwite',
'longpages' => 'Phêk seite',
'deadendpages' => 'Phêk ralthümte',
'deadendpagestext' => 'A hnuaia phêkte hian {{SITENAME}}-a phêk dang pakhat mah zawmpui an nei lo.',
'protectedpages' => 'Phêk vènhimte',
'protectedpages-indef' => 'Phêk vènhim kumhlunho chauh',
'protectedpagestext' => 'A hnuaia phêkte hi sawn emaw siam danglam theih loh tùra vènhim an ni',
'protectedtitles' => 'Hming vènhimte',
'listusers' => 'Hmangtu tlarna',
'listusers-editsonly' => 'Siam danglam nei hmangtu chauh pholang rawh',
'listusers-creationsort' => 'Siam ni indawtin tlar rawh',
'usereditcount' => 'Siam danglam {{PLURAL:||}} $1',
'usercreated' => '{{GENDER:$3|}} Ni $1, dar $2-a siam',
'newpages' => 'Phek tharte',
'newpages-username' => 'Hmangtu hming:',
'ancientpages' => 'Phek hluiho',
'move' => 'Sawnna',
'movethispage' => 'Hë phêk hi sawn rawh',
'notargettitle' => 'Tumhmun nei lo',
'nopagetitle' => 'Hetiang tumhmun phêk hi a awm lo',
'nopagetext' => 'I tumhmun sawi kher kha a awm lo niin a lang.',
'pager-newer-n' => '{{PLURAL:$1|thar zawk 1|thar zawk $1}}',
'pager-older-n' => '{{PLURAL:$1|hlui 1|hlui $1}}',
'suppress' => 'Hmuh hmaih',

# Book sources
'booksources' => 'Lehkhabu rawnte',
'booksources-search-legend' => 'Lehkhabu hnar zingah zawng rawh',
'booksources-go' => 'Khai le',

# Special:Log
'specialloguserlabel' => 'Buatsaihtu:',
'speciallogtitlelabel' => 'Tumhmun (hming emaw hmangtu):',
'log' => 'Chanchin-ziak',
'all-logs-page' => 'Chanchin-ziak vàntlang thilte:',
'log-title-wildcard' => 'Hë thüa inṭan hmingte hi zawng rawh',

# Special:AllPages
'allpages' => 'Phek zawng zawngte',
'alphaindexline' => '$1 aṭanga $2',
'nextpage' => 'Phek dawt ($1)',
'prevpage' => 'Phêk hmasa ($1)',
'allpagesfrom' => 'Hemi aṭanga inṭan hian pholang rawh:',
'allpagesto' => 'Hemi chin thleng hian:',
'allarticles' => 'Phek zawng zawngte',
'allinnamespace' => 'Phêk zawng zawng (hminghmun $1-a mi)',
'allnotinnamespace' => 'Phêk zawng zawng (hminghmun $1-a awm lo)',
'allpagesprev' => 'Hma',
'allpagesnext' => 'Dawt',
'allpagessubmit' => 'Khai le',
'allpagesprefix' => 'Hemi thuhmabeta neih zawng hi pholang rawh:',
'allpagesbadtitle' => 'Phêk hming dik lo emaw ţawng dang/wiki dang thuhmabet a hmang palh a nih hmel.
Phêk hminga hman awih loh hawrawp a hmang palh a ni mai thei bawk.',
'allpages-bad-ns' => '{{SITENAME}} hian "$1" tih hminghmun a nei lo.',
'allpages-hide-redirects' => 'Hruailuhna phêkho thup rawh',

# SpecialCachedPage
'cachedspecial-refresh-now' => 'A thar ber thlirna.',

# Special:Categories
'categories' => 'Pawlte',
'categoriespagetext' => 'A hnuaia pawl{{PLURAL:$1||te}} hian phêk emaw media a{{PLURAL:$1||n}} nei.
Hetah hian [[Special:UnusedCategories|pawl hman lohho]] pholan tel a ni lo.
[[Special:WantedCategories|Pawl mamawhho]] en bawk la.',
'categoriesfrom' => 'Hemi-a inṭan pawlho hi pholang rawh:',
'special-categories-sort-count' => 'a chhúnga thil awm zât azirin thliar rawh',
'special-categories-sort-abc' => 'a-aw-b indawtin',

# Special:DeletedContributions
'deletedcontributions' => 'Hmangtu kutthawhna paihbo tawhte',
'deletedcontributions-title' => 'Hmangtu kutthawhna paihbo tawhte',
'sp-deletedcontributions-contribs' => 'kutthawhnate',

# Special:LinkSearch
'linksearch' => 'Zawmchhuahna zawnna',
'linksearch-pat' => 'Thu zawn:',
'linksearch-ns' => 'Hminghmun:',
'linksearch-ok' => 'Zawng rawh le',
'linksearch-line' => '$1 hi $2 aţanga thlunzawm a ni',

# Special:ListUsers
'listusersfrom' => 'Hemi-a inṭanin hmangtuho pholang rawh:',
'listusers-submit' => 'Pholanna',
'listusers-noresult' => 'Hmangtu an awm lo.',
'listusers-blocked' => '(danbeh)',

# Special:ActiveUsers
'activeusers' => 'Hmangtu hlun tlarna',
'activeusers-hidebots' => 'Khawlmi thupna',
'activeusers-hidesysops' => 'Roreltu thupna',
'activeusers-noresult' => 'Hmangtu awm lo.',

# Special:ListGroupRights
'listgrouprights' => 'Hmangtu pawl dikna-chanvote',
'listgrouprights-key' => '* <span class="listgrouprights-granted">Dikna-chanvo phalsak</span>
* <span class="listgrouprights-revoked">Dikna-chanvo hnuhkirsak</span>',
'listgrouprights-group' => 'Pawl',
'listgrouprights-rights' => 'Dikna-chanvo',
'listgrouprights-helppage' => 'Help:Pawl dikna-chanvo',
'listgrouprights-members' => '(tel zawng zawng)',
'listgrouprights-addgroup' => '{{PLURAL:$2|Pawl|Pawl}} belhna: $1',

# Email user
'emailuser' => 'He hmangtu hi e-lehkha thawn rawh',
'emailusername' => 'Hmangtu hming:',
'emailusernamesubmit' => 'Thehlut rawh',
'email-legend' => 'Hmangtu dang {{SITENAME}} hnenah e-lehkha tawh rawh.',
'emailfrom' => 'Thawntu:',
'emailto' => 'Dawngtu:',
'emailsubject' => 'Thupui:',
'emailmessage' => 'Lehkha:',
'emailsend' => 'Thawnna',
'emailccme' => 'Min thawn ve nghal rawh.',
'emailccsubject' => '$1: $2 hnenah thawn bawk rawh',
'emailsent' => 'E-lehkha thawn a ni.',
'emailsenttext' => 'I e-lehkha thawn a ni.',
'emailuserfooter' => 'Hë e-lehkha hi {{SITENAME}}-a "Hmangtu e-lehkha thawn rawh" tih hmanraw hmanga $1-in $2 a thawn a ni.',

# User Messenger
'usermessage-summary' => 'Kháwlthuthawn a hnutchhiah e.',
'usermessage-editor' => 'Thuthawntu khawl',

# Watchlist
'watchlist' => 'Ralvèn',
'mywatchlist' => 'Ralvèn',
'watchlistfor2' => '$1 tan $2',
'nowatchlist' => 'Rálvèn i nei lo',
'watchlistanontext' => 'I ralvèn en tùrin emaw siamṭha tùrin $1 rawh.',
'watchnologin' => 'I la lût lo',
'watchnologintext' => 'I ralvèn tidanglam tùrin i [[Special:UserLogin|inziahluh]] a ngai.',
'addwatch' => 'Ràlvèn zingah telh rawh',
'removewatch' => 'Ralvèn zing aţang paih rawh',
'removedwatchtext' => '"[[:$1]]" i [[Special:Watchlist|ralvèn]] zing aţanga paih a ni ta.',
'watch' => 'Véng rawh',
'watchthispage' => 'He phêk hi vil rawh',
'unwatch' => 'Vil tihtawpna',
'unwatchthispage' => 'Vil tihtawpna',
'notanarticle' => 'Phêk dikdawh a ni lo.',
'notvisiblerev' => 'Hmangtu dang tihdanglamna thar paihbo a ni.',
'watchlist-details' => 'I ralvèn zing aţanga {{PLURAL:$1| phêk $1 |phêk $1}}, sawihona phêk chhiar lohvin.',
'wlheader-enotif' => '*E-lehkha inhriattirna tihnun a ni.',
'wlheader-showupdated' => "I tlawh hnuhnun ber hnua tihdanglam phêk te chu a '''thau'''va tihlan a ni.",
'watchmethod-recent' => 'phêk vèn tihdanglam leh danglam loh kan enfiah mek!',
'watchmethod-list' => 'phêk vèn tunhnaia tihdanglam a awm em kan enfiah',
'watchlistcontains' => '{{PLURAL:$1|phêk|}} $1 ral i veng.',
'wlshowlast' => 'Darkar $1 kalta-a tihdanglam tilang rawh , ni $2 kalta-a tihdanglam tilang rawh, $3 tilang rawh',
'watchlist-options' => 'Ralvèn duhdàn',

'enotif_reset' => 'Phêk zawng zawng tlawh tawh vek angin chhinchhiah rawh.',
'enotif_impersonal_salutation' => '{{SITENAME}} hmangtu',
'enotif_lastvisited' => 'I tlawh hnuhnùn ber hnu lama tihdanglam zawng zawng en i duh chuan $1 en rawh.',
'enotif_lastdiff' => 'Hë tihdanglamna hi en tùrin $1 thlír rawh.',
'enotif_anon_editor' => 'hmangtu hriat loh $1',
'created' => 'siam a ni ta',
'changed' => 'tihdanglam a ni ta',

# Delete
'deletepage' => 'Hë phêk hi paih rawh',
'confirm' => 'Tihchianna',
'excontent' => 'kentel: "$1"',
'excontentauthor' => 'kentel: "$1" (kutthawhtu awm chhun "[[Special:Contributions/$2|$2]])',
'exbeforeblank' => 'tihruah hmaa a thufùn: $1',
'exblank' => 'phêk ruak a ni',
'delete-confirm' => '"$1" paihbona',
'delete-legend' => 'Nuaibona',
'historywarning' => "'''Vàukhànna:''' I nuaibo tum phêk hian khawih danglam vawi $1{{PLURAL:$1||}} vêl zet a lo tâwk tawh.",
'confirmdeletetext' => 'Phêk pakhat leh a chanchin-ziak zawng zawng i nuaibo vek dawn mék a ni.
Hei hi i tih tum rëng a ni a, a hnuleh i hre chiang a, [[{{MediaWiki:Policy-url}}|rèlphung]] dàn zúl i zui ngèi a ni tih finfiah phawt rawh le.',
'actioncomplete' => 'A zo ta',
'actionfailed' => 'A tlawlh',
'deletedtext' => '"$1" nuaibo a ni ta.
Tün hnäia nuaibo thar chhinchhiahna $2-ah i en thei ang.',
'dellogpage' => 'Nuaibo chhinchhiahna',
'dellogpagetext' => 'A hnuaiah hian tün hnaia nuaibo tharho kan rawn chhawp chhuak e.',
'deletionlog' => 'nuaibo chhinchhiahna',
'reverted' => 'Awmphung hluiah dah lêt a ni',
'deletecomment' => 'Chhan:',
'deleteotherreason' => 'Chhan dang:',
'deletereasonotherlist' => 'Chhan dang',
'deletereason-dropdown' => '*Nuaibo chhan hluar zualte
**Phêk siamtu ngenna
**Lâkchhàwn phalphung bawhpelhna
**Inchirhthehna',
'delete-edit-reasonlist' => 'Nuaibo chhan siamṭhatna',
'delete-toobig' => 'Hë phêk hian siam danglam a tâwk ngun mangkhèng, vawi $1 {{PLURAL:$1||}} chüang zet.
Hetiang phêk nuaibo hi hrêk deuh hlek a ni, tum loh puia {{SITENAME}} tihchingpen däl tùrin.',
'delete-warning-toobig' => 'Hë phêk hian tihdanglam a lo tâwk nasa tawh mangkhèng, vawi $1 {{PLURAL:$1||}} chüang zet.
Hemi nuaibo hian {{SITENAME}} hriatna-khawlpui hnathawh a tisukuk palh thei; 
fimkhur zui hräm ang che.',

# Rollback
'rollback' => 'Siamṭhatna sûtna',
'rollback_short' => 'Sûtlêtna',
'rollbacklink' => 'sûtlêtna',
'rollbackfailed' => 'Sûtlêt a tlawlh',
'cantrollback' => 'Siamṭhatna a sûtlêt theih loh;
a siamṭhatu hnuhnüng ber hi hë phêk tawktu awm chhun a la ni tlat.',
'editcomment' => "Siamṭhatna kaihtawi: \"''\$1''\".",
'rollback-success' => '$1-in siamṭhana a sûtlêt a;
$2-in a awmphung ngäiah a dahlêt leh.',

# Edit tokens
'sessionfailure-title' => 'Hun hman tlawlh!',

# Protect
'protectlogpage' => 'Venhim chhinchhiahna',
'protectedarticle' => 'venhim: "[[$1]]"',
'modifiedarticleprotection' => '"[[$1]]" vènhimphung a thlâk',
'unprotectedarticle' => '"[[$1]]" laka vènhimna a nuaibo',
'movedarticleprotection' => 'vènhimna herremphung "[[$2]]" aṭang "[[$1]]"-ah a sawn',
'protect-title' => '"$1" vènhimphung thlâkna',
'protect-title-notallowed' => '"$1" vènhimphung thlìrna',
'prot_1movedto2' => '[[$1]] kha [[$2]]-ah sawn a ni',
'protect-badnamespace-title' => 'Hminghmun vènhim theih loh',
'protect-badnamespace-text' => 'Hë hminghmuna phêkte hi vènhim theih a ni lo.',
'protect-legend' => 'Vènhim tihchianna',
'protectcomment' => 'Chhan:',
'protectexpiry' => 'Tàwp hun:',
'protect_expiry_invalid' => 'A tàwp hun i sawi kha a hman theih loh.',
'protect_expiry_old' => 'A tàwp hun i thlan kha a thleng tawh!',
'protect-unchain-permissions' => 'Vènhimna duhthlan dang chhuah zalenna',
'protect-fallback' => '"$1" phalna nei hmangtute chauh remtihsakna',
'protect-level-autoconfirmed' => 'Mahnia infinfiah hmangtute chauh remtihsakna',
'protect-level-sysop' => 'Roreltute chauh remtihsakna',
'protect-summary-cascade' => 'venhimchhàwnna',
'protect-expiring' => '$1 (UTC) thleng',
'protect-expiring-local' => '$1 thleng',
'protect-expiry-indefinite' => 'tiamchin awm lo',
'protect-cascade' => 'Hë phêka ziahhnanho pawh vénghim vek rawh (vènhim inkhaidiat)',
'protect-cantedit' => 'Hë phêk vènhimphung hi i thlâk thei lo, siamṭhat phalna i neih loh vàng a ni.',
'protect-othertime' => 'Hun dang:',
'protect-othertime-op' => 'hun dang',
'protect-existing-expiry' => 'Tàwphun awm sa: $3, $2',
'protect-otherreason' => 'Chhan dang:',
'protect-otherreason-op' => 'Chhan dang',
'protect-dropdown' => '*Vènhim chhan lär zualte
**Inchirhthehna hlüar lutuk
**Infakmawina hleihlûak
**Siamṭhat inchuhna pawi tham
̆**Phêk tlawh nasat',
'protect-edit-reasonlist' => 'Vènhim chhan siamṭhatna',
'protect-expiry-options' => 'darkar 1:1 hour, ni 1:1 day, kar 1:1 week, kar 2:2 weeks, thla 1:1 month, thla 3:3 months, thla 6:6 months, kum 1:1 year, tiam chin awm lo:infinite',
'restriction-type' => 'Phalna:',
'restriction-level' => 'Hrêkphung:',
'minimum-size' => 'Têtzáwng tiamchin',
'maximum-size' => 'Lenzáwng bituk:',
'pagesize' => '(bait)',

# Restrictions (nouns)
'restriction-edit' => 'Siamṭhatna',
'restriction-move' => 'Sawnna',
'restriction-create' => 'Siamna',
'restriction-upload' => 'Hlànkàina',

# Restriction levels
'restriction-level-sysop' => 'vènhim pumhlùm',
'restriction-level-autoconfirmed' => 'hualna',
'restriction-level-all' => 'a enga pawh',

# Undelete
'undelete' => 'Phêk nuaibo tawhho thlìrna',
'undeletelink' => 'enna/ngaiawhtirna',
'undeleteviewlink' => 'enna',
'undelete-search-submit' => 'Zawnna',

# Namespace form on various pages
'namespace' => 'Hminghmun:',
'invert' => 'Thlan lêtna',
'namespace_association' => 'Hminghmun kaihhnawih',
'blanknamespace' => '(Phekpui)',

# Contributions
'contributions' => '{{GENDER:$1|Hmangtu}} kutthawhnate',
'contributions-title' => '$1 kutthawhnate',
'mycontris' => 'Kutthawhnate',
'contribsub2' => '$1 tan ($2) .',
'nocontribs' => 'I zawn mil tihdanglamna a awm miah lo a nih hmel.',
'uctop' => '(chung)',
'month' => 'Thla (leh a hmalam):',
'year' => 'Kum (leh a hmalam):',

'sp-contributions-newbies' => 'Siangchan tharte kut-thawhna chauh tilang rawh',
'sp-contributions-newbies-sub' => 'Siangchan thar tán',
'sp-contributions-newbies-title' => 'Siangchan thar tána hmangtu kutthawhnate',
'sp-contributions-blocklog' => 'danbeh chhinchhiahna',
'sp-contributions-uploads' => 'hlankaite',
'sp-contributions-logs' => 'chanchin-ziak',
'sp-contributions-talk' => 'sawihona',
'sp-contributions-search' => 'Kutthawhna zawnna',
'sp-contributions-username' => 'Chenhmun-IP emaw hmangtuhming:',
'sp-contributions-toponly' => 'Ka kut thawh vena chauh tilang rawh',
'sp-contributions-submit' => 'Zawng rawh le',

# What links here
'whatlinkshere' => 'Hemi zawmpuite',
'whatlinkshere-title' => '$1-a thlunzawm phêkte',
'whatlinkshere-page' => 'Phêk:',
'linkshere' => "A hnuaia phêkte hian '''[[:$1]]''' hi an thlunzawm:",
'nolinkshere' => "'''[[:$1]]'''-a zawm phek pakhat mah a awm lo.",
'isredirect' => 'Hruailuhna phêk',
'istemplate' => 'ziahhnan',
'isimage' => 'taksa thlunzawmna',
'whatlinkshere-prev' => '{{PLURAL:$1|hmasa|hmasa $1}}',
'whatlinkshere-next' => '{{PLURAL:$1|dawt|dawt $1}}',
'whatlinkshere-links' => '← thlunzawmna',
'whatlinkshere-hideredirs' => 'hruailuhna $1',
'whatlinkshere-hidetrans' => 'ziahhnante $1',
'whatlinkshere-hidelinks' => 'zawmnate $1',
'whatlinkshere-hideimages' => 'taksa zawmna $1',
'whatlinkshere-filters' => 'Thlitfimna',

# Block/unblock
'blockip' => 'Hmangtu dangbet rawh',
'blockip-title' => 'Hmangtu dangbet rawh',
'blockip-legend' => 'Hmangtu dangbet rawh',
'ipadressorusername' => 'Chenhmun-IP emaw hmangtuhming:',
'ipbexpiry' => 'Tawphun:',
'ipbreason' => 'Chhan:',
'ipbreasonotherlist' => 'Chhan dang',
'ipbsubmit' => 'Hmangtu dangbet rawh',
'ipboptions' => 'darkar 2:2 hours, ni 1:1 day, ni 3:3 days, kar 1:1 week, kar 2:2 weeks, thla 1:1 month, thla 3:3 months, thla 6:6 months, kum 1:1 year, tiam chin awm lo:infinite',
'ipb-blockingself' => 'Nangmah leh nangmah i indäl dáwn! I duh chiah maw?',
'ipblocklist' => 'Hmangtu danbeh-ho',
'ipblocklist-legend' => 'Hmangtu danbeh zawng rawh',
'blocklink' => 'danbehna',
'unblocklink' => 'phelhna',
'change-blocklink' => 'danbeh tihdanglamna',
'contribslink' => 'thawhte',
'blocklogpage' => 'Danbeh chhinchhiahna',
'blocklogentry' => '[[$1]] hi  $2 thleng danbeh a ni $3',
'block-log-flags-nocreate' => 'siangchan siam khap hrih a ni',

# Move page
'move-page' => '$1 hming thlâkna',
'move-page-legend' => 'Phêk hming thlâkna',
'movepagetext-noredirectfixer' => "Hei hi phêk hming thlâkna a ni. A phêk chanchin-hlui zawng zawng pawh a sawn nghâl vek ang.
A hming hlui kha hming thara hruailuhna phêkah chantir nghal a ni bawk dawn a ni.
[[Special:DoubleRedirects|Hming thlâk nawn]] leh [[Special:BrokenRedirects|Hming thlâk chhumbung]] a awm loh nan fimkhur ang che.
He phêk hlui zawmtute a hmun dik taka hruailuh a nih leh nih lohvah mawh i phur ang.

I hming thar vuah ang hmingpu dang phêk a awm tawh chuan he phêk hming i thlak tum hi a thlak theih loh vang, a ruak emaw, hruailuhna phêk a ni emaw, siamţhat a la ni lo emaw te a nih ngawt loh chuan.
Chumi awmzia chu, phêk awmsa i luahlantir thei lo va, mahsé a phêk hming hlui ngai i puttir leh thei thung tihna a ni.

'''Vaukhanna!'''
Phêk lar deuh tan chuan hei hi danglamna râpthlâk leh beisei loh tak i thlen thut thei tih hrechiang ang che;
phêk hming thlâkina a nghawng theih thilte i hrechiang tih infiah ang che.",
'movearticle' => 'Phêk hming thlâk tùr:',
'moveuserpage-warning' => "'''Vaukhanna:''' Hmangtu phêk i thlak dawn mek. A hmangtu phêk i thlak ringawt ang a, hmangtu hming erawh i thlâk dawn lo tih hria ang che.",
'movenologin' => 'I la lût lo',
'movenologintext' => 'Phêk hming thlâk tùrin  [[Special:UserLogin|i (inziah)luh]] a ngai.',
'movenotallowed' => 'Phêk sawn phalna i nei lo.',
'newtitle' => 'Hming thar:',
'move-watch' => 'Phêk hnar leh phêk thar vil rawh',
'movepagebtn' => 'A hming thlâk rawh le',
'pagemovedsub' => 'A hming i thlâk fel ta',
'movepage-moved' => '\'\'\'"$1" kha "$2" tia thlâk a ni ta\'\'\'',
'movepage-moved-redirect' => 'Hruailuhna phêk siam nghal a ni.',
'movelogpage' => 'Chanchin-ziak sawnna',
'movenosubpage' => 'He phêk hian phêkpéng a nei lo.',
'movereason' => 'A chhan:',
'revertmove' => 'tihlêtna',
'delete_and_move' => 'Nuaibo paha sawnna',
'delete_and_move_text' => '==Paih ngai a awm==
"[[:$1]]" tih hming pu phêk a awm tawh.
Hming thlâk thei tùra phêk awmsa paih i duh em?',
'delete_and_move_confirm' => 'Aw, a phêk awmsa chu paih ka duh',
'delete_and_move_reason' => '"[[$1]]" hming putu hmasa paih a ni ta.',
'selfmove' => 'Hming hlui leh hming thar a inang reng nia;
Amah leh amah inluahlantir a theih loh.',
'immobile-source-namespace' => '"$1" hminghmun chhunga phêkte sawn theih a ni lo',
'immobile-target-namespace' => '"$1" hminghmun chhungah phêk sawn luh theih a ni lo',
'immobile-source-page' => 'He phêk hming hi a thlâk theih loh.',

# Export
'export' => 'Phek thawnchhuahna',

# Namespace 8 related
'allmessagesname' => 'Thuthawn hming',
'allmessagesdefault' => 'Thuthawn tùr ziahsa',
'allmessages-language' => 'Ţawng:',
'allmessages-filter-submit' => 'Khai le',

# Thumbnails
'thumbnail-more' => 'Tihlenna',
'filemissing' => 'Taksa a awm lo',
'thumbnail_error' => 'Zungbï siam hlawhchham: $1',

# Special:Import
'import-token-mismatch' => 'Ṭhut chhung hriatrengna hloh hman a ni.
Khawngaihin tum nawn leh rawh.',

# Tooltip help for the actions
'tooltip-pt-userpage' => 'Nangma pual phek',
'tooltip-pt-mytalk' => 'I sawihona phêk',
'tooltip-pt-preferences' => 'I duhthlante',
'tooltip-pt-watchlist' => 'Tihdanglam tùra i ruahman phêkte',
'tooltip-pt-mycontris' => 'I kutthawhna-ho ziahchhuahna',
'tooltip-pt-login' => 'Inziak lut tura duh i ni; amaherawhchu a ţül kher lo.',
'tooltip-pt-anonlogin' => 'Inziak lut tura duh i ni; amaherawhchu, a ţül kher lo',
'tooltip-pt-logout' => 'Chhuahna',
'tooltip-ca-talk' => 'He phêk chungchang sawihona',
'tooltip-ca-edit' => 'Hemi phek hi i siamţha thei.
Khawngaihin i dahţhat/tlangzarh hmain endikna hmehkhep khu hmang ang che (hei hi hmet la a phek mawng lamah a lo lang mai ang)',
'tooltip-ca-addsection' => 'Hlawm thar ţanna',
'tooltip-ca-viewsource' => 'He phêk hi vènhim a ni
A hnar i en thei ang.',
'tooltip-ca-history' => 'Tunhmaa he phêk ennawnnate',
'tooltip-ca-protect' => 'He phek hi venghim rawh',
'tooltip-ca-unprotect' => ' Vènhimphung tihdanglamna',
'tooltip-ca-delete' => 'He phek hi paih rawh',
'tooltip-ca-undelete' => 'Hë phêk nuaibo a nih hmaa siamṭhatnate kàitho leh rawh',
'tooltip-ca-move' => 'He phek hi sawn rawh',
'tooltip-ca-watch' => 'I ralvèn zingah telh rawh',
'tooltip-ca-unwatch' => 'He phêk hi i ralvèn aţang paih rawh',
'tooltip-search' => '{{SITENAME}}-ah zawng rawh',
'tooltip-search-go' => 'He hming pu chiah chiah phêk a awm chuan tah chuan kal rawh',
'tooltip-search-fulltext' => 'He thu hi phêk tam takah zawng rawh',
'tooltip-p-logo' => 'Phekpui luhna',
'tooltip-n-mainpage' => 'Phekpui luhna',
'tooltip-n-mainpage-description' => 'Phekpui luhna',
'tooltip-n-portal' => 'He hna-hmachhawp chungchang, engnge i tih ve theih, leh thil mamawh zawnna',
'tooltip-n-currentevents' => 'Chanchin thar inziahna hmun dang zawng rawh',
'tooltip-n-recentchanges' => 'He wiki-a tihdanglam tharte',
'tooltip-n-randompage' => 'Phêk kahpah tilang rawh',
'tooltip-n-help' => 'Tah hian kaihhruaina i zawng thei ang',
'tooltip-t-whatlinkshere' => 'Hemi zawmtu wiki phêk zawng zawng',
'tooltip-t-recentchangeslinked' => 'He phêk aţanga zawm chhuah phêk tihdanglam tharte',
'tooltip-feed-rss' => 'He phêk RSS chawmna',
'tooltip-feed-atom' => 'He phêk chawmna mal',
'tooltip-t-contributions' => 'He hmangtu kut-thawhnaho hi en rawh',
'tooltip-t-emailuser' => 'He hmangtu hnenah hian e-lehkha thawn rawh',
'tooltip-t-upload' => 'Taksa hlankaina',
'tooltip-t-specialpages' => 'Phek vohbik zawng zawng tlarna',
'tooltip-t-print' => 'Chhụtkài theih',
'tooltip-t-permalink' => 'He phêk ennawnna zawmna hlun',
'tooltip-ca-nstab-main' => 'A chhung thu awm ziahna en rawh',
'tooltip-ca-nstab-user' => 'Hmangtu phêk en rawh',
'tooltip-ca-nstab-media' => 'Media phêk en rawh',
'tooltip-ca-nstab-special' => 'Hei hi phek vohbik a ni a, i siam danglam thei lo',
'tooltip-ca-nstab-project' => 'Hna-hmachhawp phêk enna',
'tooltip-ca-nstab-image' => 'Taksa phêk en rawh',
'tooltip-ca-nstab-mediawiki' => 'Khawl thuthawn en rawh',
'tooltip-ca-nstab-template' => 'Siamsa en rawh',
'tooltip-ca-nstab-help' => 'Ţanpuina phêk en rawh',
'tooltip-ca-nstab-category' => 'Pawl phêk enna',
'tooltip-minoredit' => 'Siamţhat tenauah ngai rawh',
'tooltip-save' => 'I siam ang angin tlangzarh rawh le',
'tooltip-preview' => 'I tihdanglamte endik rawh, i dahţhat hmain hei hi hmang ngei ang che',
'tooltip-diff' => 'A thua i tihdanglamte en chianna',
'tooltip-compareselectedversions' => 'Ennawnna pahnihte inan lohna en rawh',
'tooltip-watch' => 'I ralvèn zingah telh rawh',
'tooltip-watchlistedit-normal-submit' => 'Thupui paihna',
'tooltip-watchlistedit-raw-submit' => 'Ralvèn tidanglam rawh',
'tooltip-recreate' => 'Phêk paih tawh siam nawn rawh',
'tooltip-upload' => 'Hlangkai ţan rawh',
'tooltip-rollback' => '"Sûtlêtna" hian vawi khat hmeh (klik)-ah thawhtu hnuhnung ber siam danglamna a sût lêt a ni',
'tooltip-undo' => "''Tihletna'' hian he siamţhat hi a sûtlêt a, siamţhatna phek chu endikna phek angin a hawng bawk. Thu tlangpui laktawi-ah a chhan ziahna a rawn chhawp nghal bawk.",
'tooltip-preferences-save' => 'I duhthlante dahţha rawh',
'tooltip-summary' => 'A thu laktawi ziak rawh',

# Attribution
'siteuser' => '{{SITENAME}} hmangtu $1.',
'anonuser' => '{{SITENAME}} hmangtu hriat loh $1',
'lastmodifiedatby' => 'He phêk hi tihdanglam a nihna hnuhnüng ber chu  $2, $1 a ni a, a tidanglamtu chu $3 a ni.',
'othercontribs' => '$1 kutchhuak behchhana siam.',
'others' => 'a dangte',
'siteusers' => '{{SITENAME}} {{PLURAL:$2|hmangtu|hmangtute}} $1',
'anonusers' => '{{SITENAME}} hmangtu {{PLURAL:$2|hriat loh|hriat lohte}} $1.',
'creditspage' => 'Phêk siam theihna chhan',
'nocredits' => 'He phêk siamnaa bultumtute hriat a awm lo.',

# Spam protection
'spamprotectiontitle' => 'Thuthawn lawi lo danna',

# Info page
'pageinfo-title' => '"$1" chungchanga hriattirna',
'pageinfo-header-edits' => 'Siamţhatnate',
'pageinfo-views' => 'Thlir/en tawh zât',
'pageinfo-watchers' => 'Thlirtu zât',
'pageinfo-edits' => 'Siamţhat zât',
'pageinfo-authors' => 'Ziaktu hrang zât',

# Patrolling
'markaspatrolleddiff' => 'Vil angah chhiar rawh',
'markaspatrolledtext' => 'He phêk hi vil angin chhinchhiah rawh',
'markedaspatrolled' => 'Vil anga chhinchhiah a ni.',
'markedaspatrolledtext' => '[[:$1]] ennawnna thlansa hi vil anga chhinchhiah a ni.',
'markedaspatrollederror' => 'Vil anga chhinchhiah theih a ni lo',

# Patrol log
'patrol-log-page' => 'Vil chhinchhiahna',
'log-show-hide-patrol' => 'Vil chhinchhiahna $1',

# Image deletion
'filedeleteerror-long' => 'Taksa paih tum laiin buaina a lo thleng

$1',

# Browsing diffs
'previousdiff' => '←Siamţhatna hlui zâwk',
'nextdiff' => 'Siamţhatna thar zâwk→',

# Media information
'file-info-size' => '$1 × $2 pixel, taksa lenzawng: $3, MIME chi: $4',
'file-nohires' => 'A aia fiahin kan ti thei lo',
'svg-long-desc' => 'SVG taksa, tihlen theihzawng $1 × $2 pixel, taksa lenzawng: $3',
'show-big-image' => 'Tihfiahna sang ber',
'show-big-image-preview' => 'Endikna lenzawng: $1',
'file-info-gif-looped' => 'kual',

# Bad image list
'bad_image_list' => 'A ruangam chu hetiang hi a ni:

Tlarchhuahna (*-a inţan tlar) chauh pawm a ni.
Tlar pakhata zawmna hmasa ber chu taksa ţha lo zawmna a ni tùr a ni.
Chu tlara zawmna dang awm reng reng chu bîk-thil-a ngaih a ni ang; tlar chhunga taksa awmna tùr phek kan tihna a nih chu.',

# Metadata
'metadata' => 'Nepnawi',
'metadata-help' => 'He taksa hian hriatna dang a keng tel; thlalakna emaw thlachhuina amah siamna sekrek ilo aṭanga lo awm a ni mai thei.
He taksa hi a tira a nihphung tihdanglam tawh a nih chuan a chanchin ziah khuan a danglam hnu chanchin a hril kim lo mai thei.',
'metadata-expand' => 'Chanchin kimchang tihlanna',
'metadata-collapse' => 'Chanchin kimchang thup ṭhenna',
'metadata-fields' => 'Thlalâk chanchin nepnawi he thuthawna tihlante hi thlalâk phek pholan huna chanchin nepnawi dawhkan thleh a nihin tihlan a ni ang.
A bak zawng chu thuhrûk sa vek a ni ang.
* make
* model
* datetimeoriginal
* exposuretime
* fnumber
* isospeedratings
* focallength
* artist
* copyright
* imagedescription
* gpslatitude
* gpslongitude
* gpsaltitude',

# Exif tags
'exif-imagewidth' => 'Zàuzáwng',
'exif-imagelength' => 'Sànzáwng',
'exif-bitspersample' => 'Péng khata mal(bit) awm zât',
'exif-compression' => 'Sàwrtêtphung',
'exif-photometricinterpretation' => 'Rawng inpawlhphung',
'exif-orientation' => 'Hawizáwng',
'exif-samplesperpixel' => 'Péng zât',
'exif-planarconfiguration' => 'Hriatna inremphung',
'exif-ycbcrsubsampling' => 'Y leh C inthlauhbï',
'exif-ycbcrpositioning' => 'Y leh C ṭhuthmun',
'exif-xresolution' => 'Pheizáwnga tihfiahphung',
'exif-yresolution' => 'Tungzáwnga tihfiahphung',
'exif-stripoffsets' => 'Thlalâk hriattirna awmna',
'exif-rowsperstrip' => 'Ṭhuang khata tlar zât',
'exif-stripbytecounts' => 'Ṭhuang zàwr zìmtina byte awm zât',
'exif-jpeginterchangeformat' => 'JPEG SOI dahhmun',
'exif-jpeginterchangeformatlength' => 'JPEG hriattirna lenzawng (Byte-in)',
'exif-whitepoint' => 'Hmun vár rawng nihphung',
'exif-primarychromaticities' => 'Rawng bulbälte nihphung',
'exif-datetime' => 'Taksa tihdanglam hun leh ni',
'exif-imagedescription' => 'Lem hming',
'exif-make' => 'Thlalâkna siamtu',
'exif-model' => 'Thlalâkna sìamphung',
'exif-software' => 'Khawlthlûak hman',
'exif-artist' => 'Buatsaihtu',
'exif-copyright' => 'Phalna kawltu',
'exif-exifversion' => 'EXIF chhuah',
'exif-flashpixversion' => 'Flashpix chhuah chhawmdàwl theih',
'exif-colorspace' => 'Rawng hmun',
'exif-componentsconfiguration' => 'Péngtinte awmzia',
'exif-compressedbitsperpixel' => 'Lem sàwrzìmphung',
'exif-pixelydimension' => 'Lem zauzáwng',
'exif-pixelxdimension' => 'Lem sànzáwng',
'exif-usercomment' => 'Hmangtu kamchhuak',
'exif-relatedsoundfile' => 'Ritaksa laichinte',
'exif-datetimeoriginal' => 'Hriattirna siamchhuah hun leh ni',
'exif-datetimedigitized' => 'Tihkhàwl hun leh ní',
'exif-subsectime' => 'Tihdanglam hun leh ni',
'exif-exposuretime' => 'Phochhuah hun',
'exif-fnumber' => 'F zât',
'exif-source' => 'Hnar:',
'exif-writer' => 'Ziaktu',
'exif-languagecode' => 'Ţawng',
'exif-iimversion' => 'IIM chhuah',
'exif-iimcategory' => 'Pawl',

# External editor support
'edit-externally' => 'Pawnlam hmanraw hmanga tihdanglamna',
'edit-externally-help' => '(Hriat chian lehzualnan [//www.mediawiki.org/wiki/Manual:External_editors bundàn kaihhruaina phek] hi en rawh)',

# 'all' in various places, this might be different for inflected languages
'watchlistall2' => 'a vaiin',
'namespacesall' => 'a vaiin',
'monthsall' => 'a vaiin',

# action=watch/unwatch
'confirm-watch-top' => 'I ralvèn zingah i telh duh maw?',
'confirm-unwatch-button' => 'Aw le',

# Multipage image navigation
'imgmultigo' => 'Khai le!',
'imgmultigoto' => 'Phêk $1-ah kal rawh',

# Table pager
'ascending_abbrev' => '<<',
'descending_abbrev' => '>>',
'table_pager_next' => 'Phêk dawt',
'table_pager_prev' => 'Phêk hmasa',
'table_pager_first' => 'Phêk hmasa ber',
'table_pager_last' => 'Phêk hnuhnung ber',

# Watchlist editing tools
'watchlisttools-view' => 'Tihdanglam hawih enna',
'watchlisttools-edit' => 'Ralvèn enna leh siamţhatna',
'watchlisttools-raw' => 'Ralvèn siamţhatna',

# Core parser functions
'duplicate-defaultsort' => '\'\'\'Vaukhanna:\'\'\' Thliarfimna hmehkhep "$2" hian thliarfimna hmehkhep kamsa "$1" hi a luahlan.',

# Special:FileDuplicateSearch
'fileduplicatesearch-filename' => 'Taksahming',
'fileduplicatesearch-submit' => 'Zawnna',

# Special:SpecialPages
'specialpages' => 'Phek vohbikte',
'specialpages-group-login' => '(Inziah)luhna',

# External image whitelist
'external_image_whitelist' => '#He tlar hi a nih ang ngai ngaih hnuhchhiah tùr <pre>
#A hnuaiah khuan thu hman zin pangngai chhumbung (tpchb) dah rawh (a hnuaia //-te inkara mi zawng khu)
#Hei hi pawnlama zawm chhuah thlalâkte URL nen rem mil a ni ang
#Milpui neite chu thlalâk anga pholan a ni ang a, nei lo chu thlalâk zawmna tihlan a ni thung ang
# Bawhtah #-a inţan reng reng chu tuihnihna anga ngaih a ni ang
#Hawrawppui leh te thliar hran a ngai

#Tbchb zawng zawng hemi tlar chungah hian dah tùr. He tlar hi a nih ang ngai ngaia hnutchhiah tùr </pre>',

# Special:Tags
'tag-filter' => '[[Special:Tags|Sawirelh]] thlitfimna:',
'tag-filter-submit' => 'Thlitfimna',
'tags-title' => 'Sawirelh',
'tags-tag' => 'Sawirelh hming',
'tags-display-header' => 'Tihdanglam tlarna-a landàn',
'tags-description-header' => 'Awmze sawifiahna kimchang',
'tags-hitcount-header' => 'Tihdanglam sawirelhte',
'tags-edit' => 'siamṭhatna',

# New logging system
'logentry-move-move' => '$3 tih phêk kha $4-ah $1 hian a thlâk.',
'logentry-move-move-noredirect' => 'Hruailuhna phêk hnutchhiah lovin $1-in $3 phêk kha $4-ah a sawn.',
'logentry-move-move_redir' => 'Hruailuhna chungah $3 phêk kha $4-ah $1 hian a sawn.',
'logentry-move-move_redir-noredirect' => 'Hruailuhna hnutchhiah lovin $3 phêk kha $4-ah $1 hian a sawn.',
'logentry-newusers-newusers' => '$1 hian hmangtu siangchan a siam.',
'logentry-newusers-create' => '$1 hian hmangtu siangchan a siam.',
'logentry-newusers-create2' => '$1 hian hmangtu siangchan $3 a siam.',
'logentry-newusers-autocreate' => 'Siangchan $1 hi amahin a insiam.',

# Feedback
'feedback-subject' => 'Thupui:',
'feedback-message' => 'Thu',
'feedback-cancel' => 'Sûtna',

# Search suggestions
'searchsuggest-search' => 'Zawnna',
'searchsuggest-containing' => 'hemi thu telna hi...',

);
